"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _icon = _interopRequireDefault(require("../icon/icon"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class Accordion extends _react.default.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      height: 'auto',
      canExpand: false,
      isExpanded: false
    });

    _defineProperty(this, "accordionRef", /*#__PURE__*/_react.default.createRef());

    _defineProperty(this, "buttonTexts", [this.props.textOpen, this.props.textClose]);

    _defineProperty(this, "snapshotHeight", () => this.accordionRef.current ? Math.round(this.accordionRef.current.getBoundingClientRect().height) : null);

    _defineProperty(this, "toggleOpen", () => {
      const {
        clipHeight
      } = this.props;

      if (this.snapshotHeight() === clipHeight) {
        this.setState({
          isExpanded: true
        });
        this.accordionRef.current.style.height = 'auto';
        requestAnimationFrame(() => {
          const snapshotHeight = this.snapshotHeight();
          this.accordionRef.current.style.height = `${clipHeight}px`;
          requestAnimationFrame(() => {
            this.setState({
              height: snapshotHeight
            });
          });
        });
      } else {
        this.setState({
          isExpanded: false
        });
        requestAnimationFrame(() => {
          this.accordionRef.current.style.height = `${this.snapshotHeight()}px`;
          requestAnimationFrame(() => {
            this.setState({
              height: clipHeight
            });
          });
        });
      }
    });
  }

  componentDidMount() {
    requestAnimationFrame(() => {
      const {
        clipHeight
      } = this.props;

      if (clipHeight) {
        if (this.snapshotHeight() > clipHeight) {
          this.setState({
            canExpand: true,
            height: clipHeight
          });
        }
      }
    });
  }

  render() {
    const {
      children,
      clipHeight,
      handleColor
    } = this.props;
    const {
      height,
      canExpand,
      isExpanded
    } = this.state;
    const block = 'klara-ui-accordion';
    const classes = (0, _classnames.default)(block, {
      [`${block}--can-expand`]: canExpand
    });
    const style = {
      background: `linear-gradient(to bottom, transparent, ${handleColor} 30%)`
    };

    if (height !== 'auto' && height !== clipHeight) {
      const transitionend = () => {
        this.setState({
          height: 'auto'
        });
        this.accordionRef.current.removeEventListener('transitionend', transitionend);
      };

      this.accordionRef.current.addEventListener('transitionend', transitionend);
    }

    const buttonText = this.buttonTexts[Number(isExpanded)];
    return /*#__PURE__*/_react.default.createElement("div", {
      className: classes,
      ref: this.accordionRef,
      style: canExpand ? {
        height
      } : {}
    }, children, canExpand && /*#__PURE__*/_react.default.createElement("button", {
      className: `${block}__handle`,
      onClick: this.toggleOpen,
      style: style
    }, /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_icon.default, {
      shape: isExpanded ? 'chevron_up' : 'chevron_down'
    }), buttonText && /*#__PURE__*/_react.default.createElement("span", null, buttonText))));
  }

}

Accordion.propTypes = {
  children: _propTypes.default.node,
  clipHeight: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.bool]),
  textOpen: _propTypes.default.string,
  textClose: _propTypes.default.string,
  handleColor: _propTypes.default.string
};
Accordion.defaultProps = {
  children: null,
  clipHeight: false,
  textOpen: '',
  textClose: '',
  handleColor: '#ffffff'
};
Accordion.propDescriptions = {
  children: '',
  clipHeight: 'A number of pixels (example 100)',
  textOpen: 'Text to sit next to the arrow icon when closed',
  textClose: 'Text to sit next to the arrow icon when opened',
  handleColor: 'Background color for the handle'
};
var _default = Accordion;
exports.default = _default;