"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _propTypes = _interopRequireDefault(require("prop-types"));

var _react = _interopRequireWildcard(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _keyConstants = require("./../../utils/keyConstants");

var _textField = _interopRequireDefault(require("../textField/textField"));

var _badge = _interopRequireDefault(require("../badge/badge"));

var _tooltip = _interopRequireDefault(require("../tooltip/tooltip"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function overridePaste(e) {
  e.stopPropagation();
  e.preventDefault();
  const pastedText = e.clipboardData.getData('text/plain');
  document.execCommand('insertText', false, pastedText);
}

class Autocomplete extends _react.Component {
  constructor(props) {
    var _this;

    super(props);
    _this = this;

    _defineProperty(this, "onKeyDown", e => {
      switch (e.keyCode) {
        case !this.shouldShowSuggestions() && _keyConstants.KEY_UP:
        case _keyConstants.KEY_LEFT:
          this.moveInputIfEmpty(-1, e.shiftKey);
          break;

        case !this.shouldShowSuggestions() && _keyConstants.KEY_DOWN:
        case _keyConstants.KEY_RIGHT:
          this.moveInputIfEmpty(1, e.shiftKey);
          break;

        case _keyConstants.KEY_UP:
          e.preventDefault();
          this.navigateInDirection(-1);
          break;

        case _keyConstants.KEY_DOWN:
          e.preventDefault();
          this.navigateInDirection(1);
          break;

        case this.props.handleBackspace && _keyConstants.KEY_BACKSPACE:
          this.props.handleBackspace(e);
          break;

        case _keyConstants.KEY_BACKSPACE:
          this.onRemoveByBackspace();
          break;

        default:
          break;
      }
    });

    _defineProperty(this, "onEnter", e => {
      e.preventDefault();
      const suggestions = this.getSuggestions();
      const {
        activeIndex
      } = this.state;

      if (suggestions[activeIndex]) {
        this.onAddSuggestion(suggestions[activeIndex], activeIndex);
      }
    });

    _defineProperty(this, "onAddSuggestion", async (suggestion, suggestionIndex) => {
      const {
        allowMultiple,
        items
      } = this.props;
      const {
        inputIndex = items.length
      } = this.state;

      if (!this.shouldAllowInput()) {
        return;
      }

      try {
        if (suggestion.id) {
          await this.props.onAdd(suggestion.id, suggestionIndex, inputIndex);
        } else {
          await this.props.onCreate(suggestion.label, inputIndex);
        }
      } catch (e) {
        return;
      }

      this.textFieldRef.clear();
      this.setState({
        activeIndex: 0,
        inputIndex: inputIndex + 1
      }, () => {
        if (this.singleBadgeRef) {
          this.singleBadgeRef.focus();
        } else if (allowMultiple && this.textFieldRef) {
          this.textFieldRef.focus();
        }
      });
    });

    _defineProperty(this, "onInputBlur", e => {
      if (e.relatedTarget !== this.componentRef) {
        this.setState({
          activeIndex: 0,
          inputFieldHasFocus: false,
          inputIndex: undefined
        });
        this.props.onBlur(e);
      }
    });

    _defineProperty(this, "onInputChange", e => {
      if (!this.shouldAllowInput()) {
        this.textFieldRef.clear();
        return;
      }

      const {
        textContent
      } = e.target;
      this.setState({
        activeIndex: 0
      });
      this.props.onInputChange(textContent);
    });

    _defineProperty(this, "onInputFocus", e => {
      this.setState({
        inputFieldHasFocus: true
      });
      this.props.onFocus(e);
    });

    _defineProperty(this, "onRemove", index => {
      const {
        items
      } = this.props;
      const removedItem = items[index];
      this.props.onRemove(removedItem.id, index, items.slice(0, index).concat(items.slice(index + 1)));
    });

    _defineProperty(this, "onRemoveByBackspace", () => {
      const {
        value,
        items
      } = this.props;
      const {
        inputIndex = items.length,
        selectedItemIndex
      } = this.state;

      if (value.length) {
        return;
      }

      switch (inputIndex) {
        case 0:
          return;

        case selectedItemIndex + 1:
          this.onRemove(selectedItemIndex);
          this.setState({
            inputIndex: inputIndex === items.length ? undefined : inputIndex - 1
          });
          return;

        default:
          this.setState({
            selectedItemIndex: inputIndex - 1
          });
      }
    });

    _defineProperty(this, "onRemoveItemByClick", index => () => {
      this.onRemove(index);
      this.setState({
        inputIndex: undefined
      }, this.focus);
    });

    _defineProperty(this, "setTextFieldRef", ref => {
      this.textFieldRef = ref;
    });

    _defineProperty(this, "setSingleBadgeRef", ref => {
      this.singleBadgeRef = ref;
    });

    _defineProperty(this, "removeSingleItemByBackspace", e => {
      const {
        items
      } = this.props;

      if (e.key === 'Backspace' && items.length === 1) {
        this.onRemove(0);
        this.setState({
          inputIndex: 0
        }, this.focus);
      }
    });

    _defineProperty(this, "moveInputIfEmpty", (change, shiftKey) => {
      const {
        value,
        items
      } = this.props;

      if (!value) {
        const {
          inputIndex = items.length
        } = this.state;
        const newInputIndex = Math.min(items.length, Math.max(0, inputIndex + change));
        this.setState(Object.assign({
          inputIndex: newInputIndex === items.length ? undefined : newInputIndex
        }, change === -1 && shiftKey && {
          selectedItemIndex: newInputIndex,
          inputIndex
        }, change === 1 && shiftKey && {
          selectedItemIndex: inputIndex
        }));
      }
    });

    _defineProperty(this, "navigateInDirection", function () {
      let direction = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 1;

      const suggestionsLength = _this.getSuggestions().length;

      const step = Math.sign(direction);
      const steppedIndex = Math.min(suggestionsLength - 1, Math.max(_this.state.activeIndex + step, 0));

      _this.setState({
        activeIndex: steppedIndex
      }, () => {
        if (_this.selectedSuggestionRef.current && _this.selectedSuggestionRef.current.scrollIntoViewIfNeeded) {
          _this.selectedSuggestionRef.current.scrollIntoViewIfNeeded(false);
        }
      });
    });

    _defineProperty(this, "selectedSuggestionRef", /*#__PURE__*/_react.default.createRef());

    _defineProperty(this, "focus", () => {
      this.textFieldRef.focus();
    });

    _defineProperty(this, "moveInputToIndex", inputIndex => () => {
      this.setState({
        inputIndex
      }, this.focus);
    });

    _defineProperty(this, "toggleTooltip", function () {
      let id = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;

      _this.setState({
        showTooltip: id
      });
    });

    _defineProperty(this, "renderLabel", (label, tooltip, id) => {
      if (!tooltip) return label;
      const {
        showTooltip
      } = this.state;
      const {
        text,
        direction = 'down',
        zIndex = 999
      } = tooltip;
      return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("span", {
        onMouseEnter: () => this.toggleTooltip(id),
        onMouseLeave: this.toggleTooltip
      }, label), showTooltip === id && /*#__PURE__*/_react.default.createElement(_tooltip.default, {
        direction: direction,
        zIndex: zIndex
      }, text));
    });

    _defineProperty(this, "renderInput", inputProps => {
      const {
        items,
        allowMultiple
      } = this.props;
      const {
        inputIndex = items.length,
        selectedItemIndex
      } = this.state;
      const badges = items.map((item, index) => {
        const {
          id,
          label,
          tooltip = null
        } = item;
        return /*#__PURE__*/_react.default.createElement(_badge.default, {
          className: (0, _classnames.default)({
            'badge--dark': index === selectedItemIndex,
            'badge--tooltip': !!tooltip
          }),
          tabIndex: allowMultiple ? undefined : 0,
          innerRef: allowMultiple ? undefined : this.setSingleBadgeRef,
          key: id,
          icon: "remove",
          onIconClick: inputProps.disabled ? undefined : this.onRemoveItemByClick(index),
          rightAlignedIcon: true
        }, this.renderLabel(label, tooltip, id));
      });

      const inputSpan = /*#__PURE__*/_react.default.createElement("span", _extends({
        key: "input-key",
        contentEditable: !inputProps.disabled && this.shouldAllowInput(),
        spellCheck: false,
        onPaste: overridePaste
      }, inputProps, {
        onInput: inputProps.onChange,
        onKeyDown: this.onKeyDown,
        className: (0, _classnames.default)(inputProps.className, 'autocomplete__input-field')
      }));

      const getPlaceholderInput = index => /*#__PURE__*/_react.default.createElement("span", {
        key: `input-${index}`,
        className: (0, _classnames.default)('autocomplete__input-field-placeholder', {
          'autocomplete--disabled': inputProps.disabled
        }),
        onClick: inputProps.disabled ? undefined : this.moveInputToIndex(index)
      });

      const positionOfInput = Math.min(badges.length, inputIndex);
      return /*#__PURE__*/_react.default.createElement("div", {
        className: "autocomplete__pill-wrapper"
      }, badges.reduce((children, badge, index) => children.concat(index === positionOfInput ? inputSpan : getPlaceholderInput(index), badge), []).concat(positionOfInput === badges.length ? inputSpan : getPlaceholderInput(badges.length)));
    });

    _defineProperty(this, "renderSuggestionContainer", (suggestion, index) => {
      const {
        activeIndex
      } = this.state;
      const {
        renderSuggestion,
        renderCreateSuggestion
      } = this.props;
      const isActive = index === activeIndex;
      return /*#__PURE__*/_react.default.createElement("li", {
        key: suggestion.id || 'unknown-id',
        onClick: () => this.onAddSuggestion(suggestion, index),
        item: suggestion,
        index: index,
        ref: isActive ? this.selectedSuggestionRef : null,
        className: (0, _classnames.default)('autocomplete__suggestion', {
          'autocomplete__suggestion--active': isActive
        }),
        onMouseEnter: () => this.setState({
          activeIndex: index
        })
      }, suggestion.id ? renderSuggestion(suggestion.id, suggestion.label, suggestion, index) : renderCreateSuggestion(suggestion.id, suggestion.label, suggestion, index));
    });

    this.state = {
      activeIndex: 0,
      selectedItemIndex: -1,
      inputIndex: undefined,
      inputFieldHasFocus: false,
      showTooltip: null
    };
  }

  setState() {
    super.setState({
      selectedItemIndex: -1
    });
    super.setState(...arguments);
  }

  getSuggestions() {
    const {
      suggestions,
      items,
      value: inputValue
    } = this.props;

    if (this.shouldRenderCreateOption(suggestions, items)) {
      return suggestions.concat([{
        label: `${inputValue}`
      }]);
    }

    return suggestions;
  }

  shouldRenderCreateOption(suggestions, items) {
    if (!this.props.onCreate) {
      return false;
    }

    const {
      value: inputValue
    } = this.props;
    const inputValueIsEmpty = !inputValue.length;
    const inputValueIsInSuggestions = suggestions.find(s => s.label.toLowerCase() === inputValue.toLowerCase());
    const inputValueIsInItems = items.find(i => i.label.toLowerCase() === inputValue.toLowerCase());
    return !inputValueIsEmpty && !inputValueIsInSuggestions && !inputValueIsInItems;
  }

  shouldShowSuggestions() {
    return this.state.inputFieldHasFocus && this.shouldAllowInput() && this.getSuggestions().length > 0;
  }

  shouldAllowInput() {
    const {
      items,
      allowMultiple
    } = this.props;
    return allowMultiple || items.length === 0;
  }

  render() {
    const _this$props = this.props,
          {
      className,
      items,
      value,
      renderSuggestion,
      renderCreateSuggestion,
      allowMultiple
    } = _this$props,
          otherProps = _objectWithoutProperties(_this$props, ["className", "items", "value", "renderSuggestion", "renderCreateSuggestion", "allowMultiple"]);

    otherProps.preventFocus = !this.shouldAllowInput();
    return /*#__PURE__*/_react.default.createElement("div", {
      className: (0, _classnames.default)('autocomplete', className),
      tabIndex: "-1",
      ref: r => {
        this.componentRef = r;
      },
      onKeyDown: items.length === 1 && !allowMultiple ? this.removeSingleItemByBackspace : undefined
    }, /*#__PURE__*/_react.default.createElement(_textField.default, _extends({}, otherProps, {
      onFocus: this.onInputFocus,
      onBlur: this.onInputBlur,
      onChange: this.onInputChange,
      onEnter: this.onEnter,
      value: value,
      ref: this.setTextFieldRef,
      staticLabel: Boolean(items.length > 0 || this.shouldShowSuggestions()),
      renderInput: this.renderInput,
      className: (0, _classnames.default)('autocomplete__input', {
        'autocomplete__input--hidden': !this.shouldAllowInput()
      })
    })), this.shouldShowSuggestions() ? /*#__PURE__*/_react.default.createElement("ul", {
      className: "autocomplete__suggestions"
    }, this.getSuggestions().map(this.renderSuggestionContainer)) : null);
  }

}

Autocomplete.propTypes = {
  allowMultiple: _propTypes.default.bool,
  className: _propTypes.default.string,
  items: _propTypes.default.arrayOf(_propTypes.default.shape({
    label: _propTypes.default.node.isRequired,
    id: _propTypes.default.string.isRequired,
    tooltip: _propTypes.default.shape({
      text: _propTypes.default.string,
      direction: _propTypes.default.oneOf(['up', 'down', 'left', 'right']),
      zIndex: _propTypes.default.number
    })
  })).isRequired,
  value: _propTypes.default.string.isRequired,
  onCreate: _propTypes.default.func,
  onInputChange: _propTypes.default.func.isRequired,
  onAdd: _propTypes.default.func.isRequired,
  onRemove: _propTypes.default.func.isRequired,
  onFocus: _propTypes.default.func,
  onBlur: _propTypes.default.func,
  renderSuggestion: _propTypes.default.func,
  handleBackspace: _propTypes.default.func,
  renderCreateSuggestion: _propTypes.default.func,
  suggestions: _propTypes.default.arrayOf(_propTypes.default.shape({
    label: _propTypes.default.node.isRequired,
    id: _propTypes.default.string.isRequired
  })).isRequired
};
Autocomplete.defaultProps = {
  allowMultiple: true,
  className: '',
  onCreate: null,
  handleBackspace: null,
  onFocus: () => {},
  onBlur: () => {},
  renderSuggestion: (id, label) => label,
  renderCreateSuggestion: (id, label) => `${label} (skapa ny)`
};
Autocomplete.propDescriptions = {
  allowMultiple: 'Whether to allow addition of multiple pills (items) or not. If false, the input field will not be shown after adding a pill, but will appear again if it is deleted.',
  className: 'Add additional class names. The component will always have the "autocomplete" class.',
  items: 'An array representing the items. Each item in the array needs to have at least an "id" and a "label" property. Optional property "tooltip" takes an object with three properties: the required "text", and the optional "direction" and "zIndex"',
  onCreate: 'Callback that is fired when user creates a new pill given the current input value. If left out, creation is not allowed.',
  onInputChange: 'Callback that is fired when the input value changes. Expected to be used to trigger fetching of suggestions.',
  renderSuggestion: 'A function that is used to render a suggestion. If not specified, a standard rendering and styling will be given.',
  renderCreateSuggestion: 'A function that is used to render a suggestion that will be created. If not specified, a standard rendering and styling will be given.',
  suggestions: 'An array representing the suggestions. Each item in the array needs to have at least an "id" and a "label" property.'
};
Autocomplete.overridePropTypes = {
  items: {
    type: 'array',
    isRequired: 'Yes'
  },
  suggestions: {
    type: 'array',
    isRequired: 'Yes'
  }
};
var _default = Autocomplete;
exports.default = _default;