"use strict";

var _react = _interopRequireDefault(require("react"));

var _chai = require("chai");

var _enzyme = require("enzyme");

var _sinon = require("sinon");

var _autocomplete = _interopRequireDefault(require("../autocomplete"));

var _icon = _interopRequireDefault(require("../../icon/icon"));

var _badge = _interopRequireDefault(require("../../badge/badge"));

var _tooltip = _interopRequireDefault(require("../../tooltip/tooltip"));

var _spinner = _interopRequireDefault(require("../../spinner/spinner"));

var _keyConstants = require("./../../../utils/keyConstants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const suggestions = [{
  label: 'One',
  id: '11'
}, {
  label: 'Two',
  id: '22'
}, {
  label: 'Three',
  id: '33'
}];
const defaultProps = {
  loading: false,
  suggestions: [],
  items: [],
  allowMultiple: true,
  onInputChange: () => {},
  onAdd: () => {},
  onRemove: () => {},
  onCreate: null
};

function mountAutocomplete(props) {
  let autocomplete;

  const onInputChange = value => {
    autocomplete.setProps({
      value
    });
  };

  autocomplete = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_autocomplete.default, _extends({}, props, {
    onInputChange: onInputChange,
    value: ""
  })));
  return autocomplete;
}

function inputFieldOf(wrapper) {
  return wrapper.find('.autocomplete__input-field');
}

describe('Autocomplete', () => {
  let props;
  beforeEach(() => {
    props = Object.assign({}, defaultProps);
    (0, _sinon.stub)(props, 'onAdd');
    (0, _sinon.stub)(props, 'onRemove');
    (0, _sinon.stub)(props, 'onInputChange');
  });
  afterEach(() => {
    props.onAdd.restore();
    props.onRemove.restore();
    props.onInputChange.restore();
  });
  it('should display suggestions when given by prop', () => {
    const autocomplete = mountAutocomplete(_objectSpread(_objectSpread({}, props), {}, {
      suggestions
    }));
    inputFieldOf(autocomplete).simulate('focus').simulate('input', {
      target: {
        textContent: 'One'
      }
    });
    (0, _chai.expect)(autocomplete.find('li')).to.have.length(3);
  });
  it('should show a loading spinner when fetching suggestions', () => {
    const autocomplete = mountAutocomplete(_objectSpread(_objectSpread({}, props), {}, {
      loading: true,
      suggestions
    }));
    inputFieldOf(autocomplete).simulate('focus').simulate('input', {
      target: {
        textContent: 'Four'
      }
    });
    (0, _chai.expect)(autocomplete.find(_spinner.default)).to.be.present();
  });
  it('should make the first suggestion item to the "active" one', () => {
    props.suggestions = suggestions;
    const autocomplete = mountAutocomplete(props);
    inputFieldOf(autocomplete).simulate('focus');
    (0, _chai.expect)(autocomplete.find('li').first()).to.have.className('autocomplete__suggestion--active');
  });
  it('should allow navigation with arrow keys and change the active suggestion', () => {
    props.suggestions = suggestions;
    const autocomplete = mountAutocomplete(props);
    inputFieldOf(autocomplete).simulate('focus').simulate('input', {
      target: {
        textContent: ''
      }
    }).simulate('keydown', {
      keyCode: _keyConstants.KEY_DOWN
    });
    (0, _chai.expect)(autocomplete.find('li').first()).to.not.have.className('autocomplete__suggestion--active');
    (0, _chai.expect)(autocomplete.find('li').at(1)).to.have.className('autocomplete__suggestion--active');
    inputFieldOf(autocomplete).simulate('keydown', {
      keyCode: _keyConstants.KEY_UP
    });
    (0, _chai.expect)(autocomplete.find('li').first()).to.have.className('autocomplete__suggestion--active');
    (0, _chai.expect)(autocomplete.find('li').at(1)).to.not.have.className('autocomplete__suggestion--active');
  });
  it('should not "wrap around" at the top or bottom when navigating', () => {
    props.suggestions = suggestions.slice(0, 2);
    const autocomplete = mountAutocomplete(props);
    inputFieldOf(autocomplete).simulate('focus').simulate('keydown', {
      keyCode: _keyConstants.KEY_DOWN
    }).simulate('keydown', {
      keyCode: _keyConstants.KEY_DOWN
    });
    (0, _chai.expect)(autocomplete.find('li').first()).to.not.have.className('autocomplete__suggestion--active');
    (0, _chai.expect)(autocomplete.find('li').at(1)).to.have.className('autocomplete__suggestion--active');
    inputFieldOf(autocomplete).simulate('keydown', {
      keyCode: _keyConstants.KEY_UP
    }).simulate('keydown', {
      keyCode: _keyConstants.KEY_UP
    });
    (0, _chai.expect)(autocomplete.find('li').first()).to.have.className('autocomplete__suggestion--active');
    (0, _chai.expect)(autocomplete.find('li').at(1)).to.not.have.className('autocomplete__suggestion--active');
  });
  it('should reset the active item to the first one on input change', () => {
    const autocomplete = mountAutocomplete(_objectSpread(_objectSpread({}, props), {}, {
      suggestions
    }));
    inputFieldOf(autocomplete).simulate('focus').simulate('keydown', {
      keyCode: _keyConstants.KEY_DOWN
    });
    (0, _chai.expect)(autocomplete.find('li').first()).to.not.have.className('autocomplete__suggestion--active');
    (0, _chai.expect)(autocomplete.find('li').at(1)).to.have.className('autocomplete__suggestion--active');
    inputFieldOf(autocomplete).simulate('input', {
      target: {
        textContent: 'One'
      }
    });
    (0, _chai.expect)(autocomplete.find('li').first()).to.have.className('autocomplete__suggestion--active');
    (0, _chai.expect)(autocomplete.find('li').at(1)).to.not.have.className('autocomplete__suggestion--active');
  });
  it('should be able to select an item with the mouse', () => {
    const autocomplete = mountAutocomplete(_objectSpread(_objectSpread({}, props), {}, {
      suggestions
    }));
    inputFieldOf(autocomplete).simulate('focus');
    autocomplete.find('li').first().simulate('click');
    (0, _chai.expect)(props.onAdd).to.have.been.calledOnce();
    (0, _chai.expect)(props.onAdd).to.have.been.calledWith(suggestions[0].id);
  });
  it('should be able to select an item with the enter key', () => {
    const autocomplete = mountAutocomplete(_objectSpread(_objectSpread({}, props), {}, {
      suggestions
    }));
    inputFieldOf(autocomplete).simulate('focus').simulate('keypress', {
      key: 'Enter'
    });
    (0, _chai.expect)(props.onAdd).to.have.been.calledOnce();
    (0, _chai.expect)(props.onAdd).to.have.been.calledWith(suggestions[0].id);
  });
  it('should not call onAdd when there are no suggestions', () => {
    const autocomplete = mountAutocomplete(props);
    inputFieldOf(autocomplete).simulate('focus').simulate('keypress', {
      key: 'Enter'
    });
    (0, _chai.expect)(props.onAdd).to.not.have.been.called();
  });
  it('should not display the input field after choosing one item if only one can be selected', () => {
    const autocomplete = mountAutocomplete(_objectSpread(_objectSpread({}, props), {}, {
      allowMultiple: false,
      items: [suggestions[0]],
      suggestions
    }));
    inputFieldOf(autocomplete).simulate('focus');
    (0, _chai.expect)(autocomplete.find('.autocomplete__input--hidden')).to.be.present();
  });
  it('should render pills for every selected item', () => {
    const autocomplete = mountAutocomplete(_objectSpread(_objectSpread({}, props), {}, {
      items: suggestions
    }));
    (0, _chai.expect)(autocomplete.find(_badge.default)).to.have.length(3);
  });
  it('should render pill tooltip for every selected item, if they are present', () => {
    const autocomplete = mountAutocomplete(_objectSpread(_objectSpread({}, props), {}, {
      allowMultiple: true,
      suggestions,
      items: [{
        id: 't3s7yMcTester',
        label: 'Klara Klarasson',
        tooltip: {
          test: 'klara@klarasson.se'
        }
      }]
    }));
    autocomplete.find(_badge.default).find('span').simulate('mouseenter');
    (0, _chai.expect)(autocomplete.find(_tooltip.default)).to.have.length(1);
  });
  it('should be possible to remove a selected item by clicking its icon', () => {
    const autocomplete = mountAutocomplete(_objectSpread(_objectSpread({}, props), {}, {
      suggestions,
      items: suggestions
    }));
    autocomplete.find(_icon.default).first().simulate('click');
    (0, _chai.expect)(props.onRemove).to.have.been.calledOnce();
    (0, _chai.expect)(props.onRemove).to.have.been.calledWith(suggestions[0].id);
  });
  it('should be possible to remove the item using backspace; first item is selected, then it is removed', () => {
    props.suggestions = suggestions;
    props.items = suggestions;
    const autocomplete = mountAutocomplete(props);
    inputFieldOf(autocomplete).simulate('keydown', {
      keyCode: _keyConstants.KEY_BACKSPACE
    });
    (0, _chai.expect)(autocomplete.find(_badge.default).find('.badge--dark')).to.be.present();
    inputFieldOf(autocomplete).simulate('keydown', {
      keyCode: _keyConstants.KEY_BACKSPACE
    });
    (0, _chai.expect)(props.onRemove).to.have.been.calledOnce();
    (0, _chai.expect)(props.onRemove).to.have.been.calledWith(suggestions[2].id);
  });
  it('should be able to remove the pill with backspace even if the text field is not there but is hidden', () => {
    props.suggestions = suggestions;
    props.items = suggestions;
    const autocomplete = mountAutocomplete(props);
    inputFieldOf(autocomplete).simulate('keydown', {
      keyCode: _keyConstants.KEY_BACKSPACE
    });
    inputFieldOf(autocomplete).simulate('keydown', {
      keyCode: _keyConstants.KEY_BACKSPACE
    });
    (0, _chai.expect)(props.onRemove).to.have.been.calledOnce();
    (0, _chai.expect)(props.onRemove).to.have.been.calledWith(suggestions[2].id);
  });
  it('should not remove any item if the input field has a value', () => {
    props.suggestions = suggestions;
    props.items = suggestions.slice(0, 2);
    const autocomplete = mountAutocomplete(props);
    inputFieldOf(autocomplete).simulate('input', {
      target: {
        textContent: 'Two'
      }
    }).simulate('keydown', {
      keyCode: _keyConstants.KEY_BACKSPACE
    });
    (0, _chai.expect)(autocomplete.find(_badge.default).find('.badge--dark')).not.to.be.present();
  });
  it('should show the option to create a new item if specified by prop', () => {
    props.onCreate = (0, _sinon.stub)(props, 'onCreate');
    const autocomplete = mountAutocomplete(props);
    inputFieldOf(autocomplete).simulate('focus').simulate('input', {
      target: {
        textContent: 'Four'
      }
    });
    autocomplete.setProps({
      suggestions
    });
    (0, _chai.expect)(autocomplete.find('li').last().text()).to.include('skapa ny');
    (0, _chai.expect)(autocomplete.find('li').last().text()).to.include('Four');
    props.onCreate.restore();
  });
  it('should show the option to create a new item even if there are no suggestions', () => {
    props.onCreate = (0, _sinon.stub)(props, 'onCreate');
    const autocomplete = mountAutocomplete(props);
    inputFieldOf(autocomplete).simulate('focus').simulate('input', {
      target: {
        textContent: 'Anton'
      }
    });
    autocomplete.setProps({
      suggestions: []
    });
    (0, _chai.expect)(autocomplete.find('li').last().text()).to.include('skapa ny');
    (0, _chai.expect)(autocomplete.find('li').last().text()).to.include('Anton');
    props.onCreate.restore();
  });
  it('should call the prop for creating a new item when clicked', () => {
    props.onCreate = (0, _sinon.stub)(props, 'onCreate');
    const autocomplete = mountAutocomplete(props);
    inputFieldOf(autocomplete).simulate('focus').simulate('input', {
      target: {
        textContent: 'Four'
      }
    });
    autocomplete.setProps({
      suggestions
    });
    autocomplete.find('li').last().simulate('click');
    (0, _chai.expect)(props.onCreate).to.have.been.calledOnce();
    (0, _chai.expect)(props.onCreate).to.have.been.calledWith('Four');
    props.onCreate.restore();
  });
  it('should not show the option to create a new item if it is already a suggestion', () => {
    props.onCreate = (0, _sinon.stub)(props, 'onCreate');
    const autocomplete = mountAutocomplete(props);
    inputFieldOf(autocomplete).simulate('focus').simulate('input', {
      target: {
        textContent: 'three'
      }
    });
    autocomplete.setProps({
      suggestions
    });
    (0, _chai.expect)(autocomplete.find('li').last().text()).to.not.include('skapa ny');
    props.onCreate.restore();
  });
  it('should not show the option to create a new item if it is already an item', () => {
    props.onCreate = (0, _sinon.stub)(props, 'onCreate');
    props.items = [{
      id: '10',
      label: 'Four'
    }];
    const autocomplete = mountAutocomplete(props);
    inputFieldOf(autocomplete).simulate('focus').simulate('input', {
      target: {
        textContent: 'Four'
      }
    });
    autocomplete.setProps({
      suggestions
    });
    (0, _chai.expect)(autocomplete.find('li').last().text()).to.not.include('skapa ny');
    props.onCreate.restore();
  });
  it('should not show the option to create a new item if input field is empty', () => {
    const onCreate = (0, _sinon.stub)(props, 'onCreate');
    const autocomplete = mountAutocomplete(_objectSpread(_objectSpread({}, props), {}, {
      onCreate
    }));
    inputFieldOf(autocomplete).simulate('focus').simulate('input', {
      target: {
        textContent: ''
      }
    });
    autocomplete.setProps({
      suggestions
    });
    (0, _chai.expect)(autocomplete.find('li').last().text()).to.not.include('skapa ny');
    onCreate.restore();
  });
  it('should use a renderProp to render list items', () => {
    props.renderSuggestion = (id, label) => /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement("h2", null, id), /*#__PURE__*/_react.default.createElement("a", null, label));

    props.suggestions = suggestions;
    const autocomplete = mountAutocomplete(props);
    inputFieldOf(autocomplete).simulate('focus');
    (0, _chai.expect)(autocomplete.find('h2')).to.have.length(suggestions.length);
    (0, _chai.expect)(autocomplete.find('a')).to.have.length(suggestions.length);
  });
  it('should use a renderProp to render create-suggestions', () => {
    props.renderCreateSuggestion = (id, label) => /*#__PURE__*/_react.default.createElement("div", null, "`", label, " (skapa mig)`");

    props.onCreate = (0, _sinon.stub)(props, 'onCreate');
    props.suggestions = [{
      id: '1',
      label: 'gooo'
    }];
    const autocomplete = mountAutocomplete(props);
    inputFieldOf(autocomplete).simulate('focus').simulate('input', {
      target: {
        textContent: 'new'
      }
    });
    (0, _chai.expect)(autocomplete.find('li').last().text()).to.include('new (skapa mig)');
    props.onCreate.restore();
  });
  it('should handle failed onAdd/onCreate', () => {
    const autocomplete = mountAutocomplete(_objectSpread(_objectSpread({}, props), {}, {
      onCreate: async () => {
        autocomplete.setProps({
          errorText: 'error'
        });
        throw new Error('Was not added');
      }
    }));
    inputFieldOf(autocomplete).simulate('focus').simulate('input', {
      target: {
        textContent: 'Hoppas det här fungerar'
      }
    }).simulate('keypress', {
      key: 'Enter'
    });
    (0, _chai.expect)(autocomplete.text()).to.include('Hoppas det här fungerar');
    (0, _chai.expect)(autocomplete.prop('errorText')).to.equal('error');
  });
});