"use strict";

var _react = _interopRequireDefault(require("react"));

var _sinon = _interopRequireDefault(require("sinon"));

var _chai = require("chai");

var _enzyme = require("enzyme");

var _badge = _interopRequireDefault(require("../badge"));

var _icon = _interopRequireDefault(require("../../icon/icon"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Badge', () => {
  it('should render text', () => {
    const badge = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_badge.default, null, "Titel"));
    (0, _chai.expect)(badge.text()).to.eql('Titel');
  }); // TODO: test should handle undefined children

  it('should support custom classNames', () => {
    const badge = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_badge.default, {
      className: "classy"
    }, "Classy text"));
    (0, _chai.expect)(badge.hasClass('classy')).to.be.true();
  });
  describe('Icon support', () => {
    it('should render the given icon', () => {
      const badge = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_badge.default, {
        icon: "check"
      }, "Oj"));
      (0, _chai.expect)(badge.find(_icon.default)).to.be.present();
    });
    it('should not render an icon when icon prop is not set', () => {
      const badge = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_badge.default, null, "No"));
      (0, _chai.expect)(badge.find(_icon.default)).to.not.be.present();
    });
    it('should render a small icon', () => {
      const icon = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_badge.default, {
        icon: "check"
      }, "classy text")).find(_icon.default);
      (0, _chai.expect)(icon.props().small).to.be.true();
    });
    it('should support onClick', () => {
      const onIconClickSpy = _sinon.default.spy();

      const badge = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_badge.default, {
        icon: "check",
        onIconClick: onIconClickSpy
      }, "Classy text"));
      badge.find(_icon.default).simulate('click');
      (0, _chai.expect)(onIconClickSpy).to.have.been.calledOnce();
    });
  });
  describe('Type support', () => {
    it('should set a type class when a valid type prop is provided', () => {
      const badge = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_badge.default, {
        type: "dark"
      }, "A dark badge"));
      (0, _chai.expect)(badge.find('.badge--dark')).to.be.present();
    });
  });
  describe('Icon Alignment', () => {
    it('should align the icon to the right when the prop is set', () => {
      const badge = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_badge.default, {
        icon: "check",
        rightAlignedIcon: true
      }, "Icon on the right"));
      (0, _chai.expect)(badge.find('.badge--right-aligned-icon')).to.be.present();
    });
  });
});