"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _propTypes = _interopRequireDefault(require("prop-types"));

var _react = _interopRequireWildcard(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _spinner = _interopRequireDefault(require("../spinner/spinner"));

var _icon = _interopRequireDefault(require("../icon/icon"));

var _tooltip = _interopRequireDefault(require("../tooltip/tooltip"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function resolveClasses(_ref) {
  let {
    active,
    compact,
    children,
    disabled,
    icon,
    loading,
    primary,
    roundLeft,
    roundRight,
    size,
    tooltip,
    type,
    rightAlignedIcon
  } = _ref;
  const primaryClasses = {
    'button--standard': !primary,
    'button--primary': primary
  };
  const iconClasses = {
    'button--icon': icon || loading,
    'button--icon--left': !rightAlignedIcon && children && (icon || loading),
    'button--icon--right': rightAlignedIcon && children && (icon || loading),
    'button--loading': loading
  };
  const roundClasses = {
    'button--no-round-left': !roundLeft,
    'button--no-round-right': !roundRight
  };
  const typeClasses = {
    'button--default': type === 'default' && !disabled,
    'button--success': type === 'success' && !disabled,
    'button--warning': type === 'warning' && !disabled,
    'button--danger': type === 'danger' && !disabled,
    'button--inverted': type === 'inverted' && !disabled,
    'button--ghost': type === 'ghost'
  };
  const miscClasses = {
    'button--large': size === 'large',
    'button--small': size === 'small',
    'button--active': active,
    'button--compact': compact
  };
  const externalClasses = {
    'klara-ui-tooltip__hoverable': tooltip
  };
  return _objectSpread(_objectSpread(_objectSpread(_objectSpread(_objectSpread(_objectSpread({}, primaryClasses), iconClasses), typeClasses), roundClasses), miscClasses), externalClasses);
}

class Button extends _react.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "ref", /*#__PURE__*/_react.default.createRef());

    this.state = {
      mouseOver: false
    };
  }

  onMouseEnter() {
    this.setState({
      mouseOver: true
    });
  }

  onMouseLeave() {
    this.setState({
      mouseOver: false
    });
  }

  focus() {
    if (this.ref.current) {
      this.ref.current.focus();
    }
  }

  render() {
    const {
      children,
      className,
      disabled,
      href,
      icon,
      inputProps,
      loading,
      onClick,
      rel,
      rightAlignedIcon,
      target,
      tooltip
    } = this.props;
    const classes = (0, _classnames.default)('button', className, resolveClasses(this.props));
    const tooltipElement = tooltip ? /*#__PURE__*/_react.default.createElement(_tooltip.default, null, tooltip) : null;

    const spinnerComponent = loading && /*#__PURE__*/_react.default.createElement(_spinner.default, {
      type: "fading",
      size: 24,
      light: this.state.mouseOver && !disabled
    });

    const iconComponent = icon && /*#__PURE__*/_react.default.createElement(_icon.default, {
      shape: icon
    });

    const buttonIcon = spinnerComponent || iconComponent;
    const Tag = href && !disabled ? 'a' : 'button';
    return /*#__PURE__*/_react.default.createElement(Tag, _extends({
      ref: this.ref,
      className: classes,
      onMouseEnter: () => {
        this.onMouseEnter();
      },
      onMouseLeave: () => {
        this.onMouseLeave();
      },
      disabled: disabled,
      onClick: onClick
    }, href ? {
      href,
      rel,
      target
    } : {}, inputProps), tooltipElement, !rightAlignedIcon && buttonIcon, children && /*#__PURE__*/_react.default.createElement("span", null, children), rightAlignedIcon && buttonIcon);
  }

}

Button.defaultProps = {
  children: null,
  className: '',
  disabled: false,
  href: null,
  icon: '',
  inputProps: null,
  loading: false,
  onClick: () => {},
  primary: false,
  rel: null,
  rightAlignedIcon: false,
  roundLeft: true,
  roundRight: true,
  size: 'medium',
  target: null,
  tooltip: null,
  type: 'default'
};
Button.propTypes = {
  children: _propTypes.default.node,
  className: _propTypes.default.string,
  disabled: _propTypes.default.bool,
  href: _propTypes.default.string,
  icon: _propTypes.default.string,
  inputProps: _propTypes.default.object,
  //eslint-disable-line
  loading: _propTypes.default.bool,
  onClick: _propTypes.default.func,
  primary: _propTypes.default.bool,
  rel: _propTypes.default.string,
  rightAlignedIcon: _propTypes.default.bool,
  roundLeft: _propTypes.default.bool,
  roundRight: _propTypes.default.bool,
  size: _propTypes.default.oneOf(['small', 'medium', 'large']),
  target: _propTypes.default.string,
  tooltip: _propTypes.default.string,
  type: _propTypes.default.string
};
Button.propDescriptions = {
  icon: 'Any valid icon name',
  href: 'Render the button as an anchor tag, pointing to the given URL',
  tooltip: "Renders with klara-ui's tooltip component. Always at left side.",
  inputProps: 'Passes props to underlying tag element',
  size: 'Can be either small, medium or large, defaults to medium'
};
var _default = Button;
exports.default = _default;