"use strict";

var _react = _interopRequireDefault(require("react"));

var _chai = require("chai");

var _enzyme = require("enzyme");

var _sinon = _interopRequireDefault(require("sinon"));

var _button = _interopRequireDefault(require("./../button"));

var _standardShapes = _interopRequireDefault(require("../../../utils/standardShapes"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Button', () => {
  it('should render a button', () => {
    const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, null));
    (0, _chai.expect)(button).to.have.className('button--standard');
  });
  it('should render text', () => {
    const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, null, "panda"));
    (0, _chai.expect)(button).to.have.text('panda');
  });
  it('should render large button', () => {
    const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
      text: "panda",
      size: "large"
    }));
    (0, _chai.expect)(button).to.have.className('button--large');
  });
  it('should render a disabled button', () => {
    const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
      disabled: true
    }));
    (0, _chai.expect)(button).to.have.attr('disabled');
  });
  it('should render a custom className', () => {
    const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
      className: "my-custom-class-name"
    }));
    (0, _chai.expect)(button).to.have.className('my-custom-class-name');
  });
  describe('Button icons', () => {
    it('should render a regular size icon button for all standard shapes', () => {
      Object.keys(_standardShapes.default).forEach(iconName => {
        const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
          icon: iconName
        }));
        (0, _chai.expect)(button).to.have.className('button--icon');
        (0, _chai.expect)(button.find('svg')).to.be.present();
        (0, _chai.expect)(button.find('svg')).to.have.attr('viewBox', '0 0 24 24');
      });
    });
    it('should render a large size icon button for all standard shapes', () => {
      Object.keys(_standardShapes.default).forEach(iconName => {
        const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
          icon: iconName,
          size: "large"
        }));
        (0, _chai.expect)(button).to.have.className('button--icon');
        (0, _chai.expect)(button.find('svg')).to.be.present();
        (0, _chai.expect)(button.find('svg')).to.have.attr('viewBox', '0 0 24 24');
      });
    });
  });
  describe('Primary Buttons', () => {
    it('should render a standard button', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, null));
      (0, _chai.expect)(button).to.have.className('button--standard');
    });
    it('should render a primary button', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        primary: true
      }));
      (0, _chai.expect)(button).to.have.className('button--primary');
    });
  });
  describe('Active Buttons', () => {
    it('should render an active button', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        active: true
      }));
      (0, _chai.expect)(button).to.have.className('button--active');
    });
  });
  describe('Button types', () => {
    it('should render a button with default type', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, null));
      (0, _chai.expect)(button).to.have.className('button--default');
    });
    it('should render a button with explicit default type', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        type: "default"
      }));
      (0, _chai.expect)(button).to.have.className('button--default');
    });
    it('should render a button with success type', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        type: "success"
      }));
      (0, _chai.expect)(button).to.have.className('button--success');
    });
    it('should render a button with warning type', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        type: "warning"
      }));
      (0, _chai.expect)(button).to.have.className('button--warning');
    });
    it('should render a button with danger type', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        type: "danger"
      }));
      (0, _chai.expect)(button).to.have.className('button--danger');
    });
    it('should render a button with inverted type', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        type: "inverted"
      }));
      (0, _chai.expect)(button).to.have.className('button--inverted');
    });
  });
  describe('Button onClick', () => {
    let onClick;
    before(() => {
      onClick = _sinon.default.stub();
    });
    it('should invoke onClick if button is clicked', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        onClick: onClick
      }));
      button.simulate('click');
      (0, _chai.expect)(onClick).to.have.been.called();
    });
  });
  describe('Loading button', () => {
    it('should render a loading button', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        loading: true
      }));
      (0, _chai.expect)(button).to.have.className('button--loading');
      (0, _chai.expect)(button.find('svg')).to.be.present();
    });
  });
  describe('Rounded corners', () => {
    it('Remove left rounded corners', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        roundLeft: false
      }));
      (0, _chai.expect)(button).to.have.className('button--no-round-left');
    });
    it('Remove right rounded corners', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        roundRight: false
      }));
      (0, _chai.expect)(button).to.have.className('button--no-round-right');
    });
  });
  describe('Href prop', () => {
    it('should render an anchor tag as the container when given an href prop', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        href: "http://www.example.com"
      }));
      (0, _chai.expect)(button.find('a.button')).to.exist();
    });
    it('should render a button tag when an href is not provided', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, null));
      (0, _chai.expect)(button.find('button')).to.exist();
      (0, _chai.expect)(button.find('a')).to.not.exist();
    });
  });
  describe('Button tooltips', () => {
    it('should show when tooltip prop is passed, button is hovered and show the correct text', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        tooltip: "Klara 4EVAH"
      }));
      button.simulate('mouseEnter');
      (0, _chai.expect)(button.find('.klara-ui-tooltip')).to.exist();
      (0, _chai.expect)(button.text()).to.equal('Klara 4EVAH');
    });
    it('should NOT show when tooltip prop is absent', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        icon: "add"
      }));
      (0, _chai.expect)(button.find('.klara-ui-tooltip')).to.not.exist();
    });
  });
  describe('Button target', () => {
    it('should pass the target prop through to the underlying node', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        href: "http://expressen.se",
        target: "_blank"
      }));
      (0, _chai.expect)(button.find('a').prop('target')).to.eql('_blank');
    });
    it('should not set target by default', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, null));
      (0, _chai.expect)(button.find('button').prop('target')).not.to.exist();
    });
  });
  describe('Custom input props', () => {
    it('should render a submit button if submit type is provided', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        inputProps: {
          type: 'submit'
        }
      }));
      (0, _chai.expect)(button).to.have.attr('type', 'submit');
    });
    it('should render a button with a button type if it is provided', () => {
      const button = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_button.default, {
        inputProps: {
          type: 'button'
        }
      }));
      (0, _chai.expect)(button).to.have.attr('type', 'button');
    });
  });
});