"use strict";

var _react = _interopRequireDefault(require("react"));

var _chai = require("chai");

var _enzyme = require("enzyme");

var _sinon = _interopRequireDefault(require("sinon"));

var _checkbox = _interopRequireDefault(require("../checkbox"));

var _icon = _interopRequireDefault(require("../../icon/icon"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Checkbox', () => {
  it('should render a Checkbox', () => {
    const checkbox = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_checkbox.default, {
      label: "This is our label",
      onChange: () => {},
      checked: false
    }));
    (0, _chai.expect)(checkbox).to.have.text('This is our label');
    (0, _chai.expect)(checkbox).to.have.className('checkbox-field');
  });
  it('should be disabled when disabled', () => {
    const checkbox = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_checkbox.default, {
      disabled: true,
      checked: false,
      onChange: () => {}
    }));
    (0, _chai.expect)(checkbox).to.be.disabled();
  });
  it('should call its callback when clicked', () => {
    const onChange = _sinon.default.stub();

    const checkbox = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_checkbox.default, {
      label: "This is our label",
      onChange: onChange,
      checked: false
    }));
    checkbox.simulate('click');
    (0, _chai.expect)(onChange).to.have.been.calledOnce();
  });
  it('should render correct icon when checked', () => {
    const checkbox = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_checkbox.default, {
      label: "This is our label",
      onChange: () => {},
      checked: true
    }));
    (0, _chai.expect)(checkbox.find(_icon.default).props().shape).to.equal('checked_box');
  });
  it('should render correct icon when unchecked', () => {
    const checkbox = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_checkbox.default, {
      label: "This is our label",
      onChange: () => {},
      checked: false
    }));
    (0, _chai.expect)(checkbox.find(_icon.default).props().shape).to.equal('check_box');
  });
  it('should render a custom css class', () => {
    const checkbox = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_checkbox.default, {
      label: "This is our label",
      onChange: () => {},
      checked: false,
      className: "my-custom-class"
    }));
    (0, _chai.expect)(checkbox).to.have.className('my-custom-class');
  });
});