"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const timeConstants = require('./time');

const language = require('./language');

const assembleString = parts => parts.filter(x => x).reduce((str, part) => `${str}${str.length ? ' ' : ''}${part}`, '');

const getHours = date => `0${date.getHours()}`.slice(-2);

const getMinutes = date => `0${date.getMinutes()}`.slice(-2);

const getWeekday = (date, _ref) => {
  let {
    longFormat
  } = _ref;
  const dayString = language.weekdays[date.getDay()];
  return longFormat ? dayString : dayString.substr(0, 3);
};

const getMonth = (date, _ref2) => {
  let {
    longFormat
  } = _ref2;
  const monthString = language.months[date.getMonth()];
  return longFormat ? monthString : monthString.substr(0, 3);
};

const format = function format(now, input) {
  let {
    withTime,
    withWeekday,
    longFormat
  } = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  const nowDate = new Date(now);
  const inputDate = new Date(input);
  const diffAbs = Math.abs(nowDate.getTime() - input);
  const weekday = withWeekday ? getWeekday(inputDate, {
    longFormat
  }) : null;
  const day = inputDate.getDate();
  const month = getMonth(inputDate, {
    longFormat
  });
  const year = nowDate.getYear() !== inputDate.getYear() ? inputDate.getUTCFullYear() : null;
  const time = withTime ? `${getHours(inputDate)}.${getMinutes(inputDate)}` : null; // Should we render with igår, idag or imorgon?

  if (diffAbs < timeConstants.day && nowDate.getDate() === inputDate.getDate()) {
    return assembleString([language.words.today, time, year]);
  } else if (diffAbs < 2 * timeConstants.day) {
    if (nowDate.getDate() === inputDate.getDate() + 1) {
      return assembleString([language.words.yesterday, time, year]);
    } else if (nowDate.getDate() === inputDate.getDate() - 1) {
      return assembleString([language.words.tomorrow, time, year]);
    }
  }

  return assembleString([weekday, day, month, year, time]);
};

const formatRelative = (now, input, options) => {
  const nowDate = new Date(now);
  const inputDate = new Date(input);
  const diff = now - input;
  const diffAbs = Math.abs(diff);
  const isSameDay = diff < 24 * timeConstants.hour && nowDate.getDay() === inputDate.getDay();
  if (diffAbs < 10 * timeConstants.second) return 'alldeles nyss'; // Second precision

  if (diffAbs < timeConstants.minute) {
    const seconds = Math.floor(diffAbs / timeConstants.second);
    return diff > 0 ? `${seconds} sekunder sedan` : `om ${seconds} sekunder`;
  } // Minute precision


  if (diffAbs < timeConstants.hour) {
    const minutes = Math.floor(diffAbs / timeConstants.minute);
    return diff > 0 ? `${minutes} minuter sedan` : `om ${minutes} minuter`;
  } // Hour precision


  if (isSameDay) {
    const hours = Math.floor(diffAbs / timeConstants.hour);
    return diff > 0 ? `${hours} timmar sedan` : `om ${hours} timmar`;
  }

  return format(now, input, options);
};

class DateFormat extends _react.default.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      now: Date.now()
    });

    _defineProperty(this, "tick", () => {
      this.setState({
        now: Date.now()
      });
      this.pollTimeout = setTimeout(this.tick, this.props.tickInterval);
    });
  }

  static format(now, input) {
    let options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    return options.relative ? formatRelative(now, input, options) : format(now, input, options);
  }

  componentDidMount() {
    if (this.props.autoUpdate) {
      this.pollTimeout = setTimeout(this.tick, this.props.tickInterval);
    }
  }

  componentWillUnmount() {
    clearTimeout(this.pollTimeout);
  }

  render() {
    const {
      now
    } = this.state;

    const _this$props = this.props,
          {
      input,
      render
    } = _this$props,
          options = _objectWithoutProperties(_this$props, ["input", "render"]);

    return render(DateFormat.format(now, input, options));
  }

}

DateFormat.propTypes = {
  autoUpdate: _propTypes.default.bool,
  input: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.number]).isRequired,
  longFormat: _propTypes.default.bool,
  relative: _propTypes.default.bool,
  render: _propTypes.default.func,
  tickInterval: _propTypes.default.number,
  withTime: _propTypes.default.bool,
  withWeekday: _propTypes.default.bool
};
DateFormat.defaultProps = {
  autoUpdate: false,
  longFormat: false,
  relative: false,
  render: val => /*#__PURE__*/_react.default.createElement("span", null, val),
  tickInterval: 1000,
  withTime: false,
  withWeekday: false
};
DateFormat.propDescriptions = {
  input: 'The timestamp as number of milliseconds since 1970-01-01 00:00.00',
  render: 'A function to render the actual date. Receives the output string as a parameter.',
  withTime: 'Show the time along with the date.'
};
var _default = DateFormat;
exports.default = _default;