"use strict";

var _react = _interopRequireDefault(require("react"));

var _chai = require("chai");

var _enzyme = require("enzyme");

var _sinon = _interopRequireDefault(require("sinon"));

var _dateFormat = _interopRequireDefault(require("../dateFormat"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable no-mixed-operators */
const time = require('../time');

const now = 1516627620000; // 2018-01-22 14:27.00 UTC+1

describe('DateFormat', () => {
  let clock;
  beforeEach(() => {
    clock = _sinon.default.useFakeTimers({
      now
    });
  });
  afterEach(() => {
    clock.restore();
  });
  it('should render a basic date format if only the input is set', () => {
    (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
      input: now - 2 * time.day
    })).text()).to.equal('20 jan');
    (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
      input: now + 3 * time.month
    })).text()).to.equal('22 apr');
  });
  it('should render with the year if needed', () => {
    (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
      input: now - 2 * time.year
    })).text()).to.contain('2 feb 2016');
    (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
      input: now + 5 * time.year
    })).text()).to.equal('27 dec 2022');
  });
  it('should render with the time if withTime is set', () => {
    (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
      withTime: true,
      input: now - 2 * time.day
    })).text()).to.equal('20 jan 14.27');
    (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
      withTime: true,
      input: now + 3 * time.week
    })).text()).to.equal('12 feb 14.27');
    (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
      withTime: true,
      input: now + time.year + 47 * time.week
    })).text()).to.equal('12 dec 2019 14.27');
  });
  it('should render a longer format if longFormat is set', () => {
    (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
      input: now - 2 * time.day,
      longFormat: true
    })).text()).to.equal('20 januari');
    (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
      input: now + 2 * time.year,
      longFormat: true
    })).text()).to.equal('12 januari 2020');
    (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
      input: now - 1 * time.week,
      longFormat: true,
      withTime: true
    })).text()).to.equal('15 januari 14.27');
  });
  it('should render with weekday if withWeekday is set', () => {
    (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
      input: now - 5 * time.day,
      withWeekday: true
    })).text()).to.equal('tor 17 jan');
    (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
      input: now - 7 * time.day,
      withWeekday: true,
      longFormat: true
    })).text()).to.equal('tisdag 15 januari');
  });
  it('should render with "igår", "idag", och "imorgon" instead of the dates', () => {
    (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
      input: now - 2 * time.hour,
      withTime: true
    })).text()).to.equal('idag 12.27');
    (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
      input: now - 1 * time.day,
      withTime: true
    })).text()).to.equal('igår 14.27');
    (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
      input: now + 1 * time.day,
      withTime: true
    })).text()).to.equal('imorgon 14.27');
  });
  it('should render using the render prop', () => {
    const wrap = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
      input: now,
      render: date => /*#__PURE__*/_react.default.createElement("button", null, date)
    }));
    (0, _chai.expect)(wrap.find('button')).to.be.present();
  });
  describe('Relative Dates', () => {
    it('should consider timestamps within 10 seconds as "now"', () => {
      (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
        input: now + 5 * time.second,
        relative: true
      })).text()).to.equal('alldeles nyss');
      (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
        input: now - 9 * time.second,
        relative: true
      })).text()).to.equal('alldeles nyss');
    });
    describe('Past Timestamps', () => {
      it('should render anything less than an hour ago with minute precision', () => {
        (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
          input: now - 3 * time.minute,
          relative: true
        })).text()).to.equal('3 minuter sedan');
        (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
          input: now - 43 * time.minute,
          relative: true
        })).text()).to.equal('43 minuter sedan');
        (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
          input: now - 59 * time.minute,
          relative: true
        })).text()).to.equal('59 minuter sedan');
      });
      it('should render anything from 1 to 23 hours ago, while within the same day, with hour precision', () => {
        (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
          input: now - 2 * time.hour,
          relative: true
        })).text()).to.equal('2 timmar sedan');
        (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
          input: now - 10 * time.hour,
          relative: true
        })).text()).to.equal('10 timmar sedan');
        (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
          input: now - 15 * time.hour,
          relative: true
        })).text()).to.equal('igår');
      });
    });
    describe('Future Timestamps', () => {
      it('should render anything within an hour with minute precision', () => {
        (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
          input: now + 3 * time.minute,
          relative: true
        })).text()).to.equal('om 3 minuter');
        (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
          input: now + 43 * time.minute,
          relative: true
        })).text()).to.equal('om 43 minuter');
        (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
          input: now + 59 * time.minute,
          relative: true
        })).text()).to.equal('om 59 minuter');
      });
      it('should render anything within 1 to 23 hours, while within the same day, with hour precision', () => {
        (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
          input: now + 1 * time.hour,
          relative: true
        })).text()).to.equal('om 1 timmar');
        (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
          input: now + 8.5 * time.hour,
          relative: true
        })).text()).to.equal('om 8 timmar');
        (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
          input: now + 15 * time.hour,
          relative: true
        })).text()).to.equal('imorgon');
      });
    });
    describe('Live Updates', () => {
      it('should not be live updating by default', () => {
        const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
          input: now - 20 * time.second,
          relative: true
        }));
        (0, _chai.expect)(wrapper.text()).to.equal('20 sekunder sedan');
        clock.tick(10000);
        (0, _chai.expect)(wrapper.text()).to.equal('20 sekunder sedan');
      });
      it('should update automatically if autoUpdate is set', () => {
        const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_dateFormat.default, {
          input: now - 20 * time.second,
          relative: true,
          autoUpdate: true
        }));
        (0, _chai.expect)(wrapper.text()).to.equal('20 sekunder sedan');
        clock.tick(10000);
        (0, _chai.expect)(wrapper.text()).to.equal('30 sekunder sedan');
        clock.tick(120000);
        (0, _chai.expect)(wrapper.text()).to.equal('2 minuter sedan');
      });
    });
    describe('Format through a staic method', () => {
      it('should render a normal value on the defined format', () => {
        (0, _chai.expect)(_dateFormat.default.format(now, now + 3 * time.day)).to.equal('25 jan');
      });
      it('should render a relative value if that option is specified', () => {
        (0, _chai.expect)(_dateFormat.default.format(now, now + 1 * time.day, {
          relative: true
        })).to.equal('imorgon');
        (0, _chai.expect)(_dateFormat.default.format(now, now + 3 * time.minute, {
          relative: true
        })).to.equal('om 3 minuter');
        (0, _chai.expect)(_dateFormat.default.format(now, now + 3 * time.minute, {
          relative: true
        })).to.equal('om 3 minuter');
      });
    });
  });
});