"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _moment = _interopRequireDefault(require("moment"));

var _reactDategrid = _interopRequireDefault(require("react-dategrid"));

var _classnames = _interopRequireDefault(require("classnames"));

var _timepicker = _interopRequireDefault(require("./timepicker"));

var _keyConstants = require("../../utils/keyConstants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

_moment.default.locale('sv');

function modifyDateWithArrowKey(_ref, dateToModify) {
  let {
    keyCode,
    shiftKey,
    altKey
  } = _ref;
  const date = dateToModify.clone();
  /* eslint-disable no-multi-spaces, default-case */

  switch (keyCode) {
    case shiftKey && altKey && _keyConstants.RIGHT_ARROW:
    case shiftKey && _keyConstants.RIGHT_ARROW:
      return date.add(1, 'month');

    case altKey && _keyConstants.RIGHT_ARROW:
    case _keyConstants.RIGHT_ARROW:
      return date.add(1, 'day');

    case shiftKey && altKey && _keyConstants.LEFT_ARROW:
    case shiftKey && _keyConstants.LEFT_ARROW:
      return date.subtract(1, 'month');

    case altKey && _keyConstants.LEFT_ARROW:
    case _keyConstants.LEFT_ARROW:
      return date.subtract(1, 'day');

    case shiftKey && altKey && _keyConstants.DOWN_ARROW:
      return date.subtract(1, 'minute');

    case shiftKey && _keyConstants.DOWN_ARROW:
      return date.subtract(1, 'hour').minutes(0);

    case altKey && _keyConstants.DOWN_ARROW:
      return date.subtract(date.minutes() % 15 || 15, 'minutes');

    case _keyConstants.DOWN_ARROW:
      return date.add(1, 'week');

    case shiftKey && altKey && _keyConstants.UP_ARROW:
      return date.add(1, 'minute');

    case shiftKey && _keyConstants.UP_ARROW:
      return date.add(1, 'hour').minutes(0);

    case altKey && _keyConstants.UP_ARROW:
      return date.add(15 - date.minutes() % 15, 'minutes');

    case _keyConstants.UP_ARROW:
      return date.subtract(1, 'week');
  }
  /* eslint-enable no-multi-spaces, default-case */


  return null;
}

class Datepicker extends _react.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      datePickerHasFocus: false,
      view: this.props.selectedDate || (0, _moment.default)()
    });

    _defineProperty(this, "onKeyUp", event => {
      switch (event.keyCode) {
        case _keyConstants.KEY_ENTER:
          return this.props.onEnter();

        case _keyConstants.KEY_ESCAPE:
          return this.props.onEscape();

        default:
          return null;
      }
    });

    _defineProperty(this, "onKeyDown", event => {
      if (this.state.datePickerHasFocus && [_keyConstants.LEFT_ARROW, _keyConstants.DOWN_ARROW, _keyConstants.UP_ARROW, _keyConstants.RIGHT_ARROW].includes(event.keyCode)) {
        event.preventDefault();
        const newDate = modifyDateWithArrowKey(event, this.props.selectedDate || (0, _moment.default)());

        if (this.props.isDateValid(newDate)) {
          this.setState({
            view: newDate
          });
          this.onChange(newDate);
        }
      }
    });

    _defineProperty(this, "onDayClick", day => {
      this.setState({
        view: day
      });
      this.onChange(day);
    });

    _defineProperty(this, "onChange", day => {
      this.props.onChange(day);
    });

    _defineProperty(this, "onViewChange", view => {
      this.setState({
        view
      });
    });

    _defineProperty(this, "setDatePickerRef", el => {
      this.datePickerRef = el;
    });

    _defineProperty(this, "focus", () => {
      this.containerRef.focus();
    });

    _defineProperty(this, "containerRefCallback", el => {
      this.containerRef = el;
    });

    _defineProperty(this, "focusDatePicker", e => {
      if (!e.nativeEvent.path || this.containerRef === e.nativeEvent.path[0]) {
        this.setState({
          datePickerHasFocus: true
        });
      }
    });

    _defineProperty(this, "blurDatePicker", () => {
      this.setState({
        datePickerHasFocus: false
      });
    });
  }

  componentDidUpdate(prevProps) {
    if (this.props.selectedDate && prevProps.selectedDate !== this.props.selectedDate) {
      this.setState({
        view: this.props.selectedDate
      });
    }
  }

  render() {
    const {
      view
    } = this.state;
    const {
      withoutTimepicker,
      isDateValid,
      selectedDate
    } = this.props;
    return /*#__PURE__*/_react.default.createElement("div", {
      className: "kui-datepicker kui-datepicker__wrapper",
      onKeyDown: this.onKeyDown,
      onKeyUp: this.onKeyUp,
      tabIndex: 0,
      onFocus: this.focusDatePicker,
      onBlur: this.blurDatePicker,
      ref: this.containerRefCallback
    }, /*#__PURE__*/_react.default.createElement(_reactDategrid.default, {
      className: "kui-datepicker__calendar",
      view: view,
      onViewChange: this.onViewChange,
      renderTitle: currentView => {
        let str = currentView.format('MMMM YYYY');
        str = `${str.substr(0, 1).toUpperCase()}${str.substr(1)}`;
        return /*#__PURE__*/_react.default.createElement("div", {
          className: "kui-datepicker__title"
        }, str);
      },
      renderPreviousNavigation: props => /*#__PURE__*/_react.default.createElement("div", _extends({
        className: "kui-datepicker__previous"
      }, props), "\u2039"),
      renderNextNavigation: props => /*#__PURE__*/_react.default.createElement("div", _extends({
        className: "kui-datepicker__next"
      }, props), "\u203A"),
      renderWeekday: index => /*#__PURE__*/_react.default.createElement("strong", null, ['Må', 'Ti', 'On', 'To', 'Fr', 'Lö', 'Sö'][index]),
      renderDay: (day, currentView) => {
        const {
          classNameForDate,
          highlightToday
        } = this.props;
        const classes = (0, _classnames.default)('kui-datepicker__day', {
          'kui-datepicker__day--today': highlightToday && day.isSame((0, _moment.default)(), 'day'),
          'kui-datepicker__day--outside-month': !day.isSame(currentView, 'month'),
          'kui-datepicker__day--selected': selectedDate && day.isSame(selectedDate, 'day'),
          'kui-datepicker__day--invalid': !isDateValid(day)
        }, classNameForDate(day));
        return /*#__PURE__*/_react.default.createElement("div", {
          onClick: isDateValid(day) ? () => this.onDayClick(day) : () => {},
          className: classes
        }, day.date());
      }
    }), !withoutTimepicker && /*#__PURE__*/_react.default.createElement(_timepicker.default, {
      date: selectedDate,
      onChange: this.onChange
    }));
  }

}

Datepicker.propTypes = {
  isDateValid: _propTypes.default.func,
  onChange: _propTypes.default.func,
  highlightToday: _propTypes.default.bool,
  onEnter: _propTypes.default.func,
  onEscape: _propTypes.default.func,
  classNameForDate: _propTypes.default.func,
  selectedDate: _propTypes.default.instanceOf(_moment.default),
  withoutTimepicker: _propTypes.default.bool
};
Datepicker.defaultProps = {
  isDateValid: () => true,
  highlightToday: true,
  onChange: () => {},
  onEnter: () => {},
  onEscape: () => {},
  classNameForDate: () => {},
  selectedDate: null,
  withoutTimepicker: false
};
Datepicker.propDescriptions = {
  selectedDate: 'The currently selected date. Should be a valid Moment instance',
  onChange: 'Function which will receive the new timestamp as a moment instance',
  withoutTimepicker: 'Should the timepicker be included?',
  disabled: 'Should the datepicker be disabled?',
  isDateValid: 'Dates in the passed should be diabled',
  classNameForDate: 'Optionally override the classes for a given day, return string'
};
var _default = Datepicker;
exports.default = _default;