"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _popover = _interopRequireDefault(require("../popover/popover"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class AnchoredMenu extends _react.default.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      open: false
    });

    _defineProperty(this, "ref", /*#__PURE__*/_react.default.createRef());

    _defineProperty(this, "anchorRef", /*#__PURE__*/_react.default.createRef());

    _defineProperty(this, "toggleIsOpen", () => this.state.open ? this.close() : this.open());

    _defineProperty(this, "open", () => {
      this.setState({
        open: true
      });
      const root = this.ref.current.getRootNode();
      root.addEventListener('click', this.handleAllClicks);
      this.props.onOpen();
    });

    _defineProperty(this, "close", () => {
      this.setState({
        open: false
      });
      const root = this.ref.current.getRootNode();
      root.removeEventListener('click', this.handleAllClicks);
      this.props.onClose();
    });

    _defineProperty(this, "focus", () => {
      if (this.anchorRef.current && this.anchorRef.current.focus) {
        this.anchorRef.current.focus();
      }
    });

    _defineProperty(this, "handleAllClicks", (_ref) => {
      let {
        target
      } = _ref;
      const node = this.ref.current;
      return node.contains(target) || this.close();
    });

    _defineProperty(this, "handleKeyDown", event => {
      switch (event.key) {
        case 'Escape':
          return this.close();

        case 'ArrowDown':
        case 'ArrowUp':
          event.preventDefault();
          return this.state.open ? this.props.onArrowKey(event.key) : this.open();

        case 'Tab':
          return this.state.open && event.preventDefault();

        case 'Enter':
        case ' ':
          return this.state.open && this.props.onEnter(event, {
            closeMenu: this.close,
            focusAnchor: this.focus
          });

        default:
          return null;
      }
    });
  }

  componentWillUnmount() {
    const root = this.ref.current.getRootNode();
    root.removeEventListener('click', this.handleAllClicks);
  }

  render() {
    const _this$props = this.props,
          {
      popoverProps,
      renderMenu,
      renderAnchor,
      onEnter,
      onArrowKey,
      onOpen
    } = _this$props,
          wrapperProps = _objectWithoutProperties(_this$props, ["popoverProps", "renderMenu", "renderAnchor", "onEnter", "onArrowKey", "onOpen"]);

    return /*#__PURE__*/_react.default.createElement("div", _extends({}, wrapperProps, {
      ref: this.ref,
      onKeyDown: this.handleKeyDown
    }), this.props.renderAnchor(this.toggleIsOpen, this.anchorRef, this.state.open), this.state.open && /*#__PURE__*/_react.default.createElement(_popover.default, _extends({}, this.props.popoverProps, {
      anchorNode: this.anchorRef.current
    }), this.props.renderMenu({
      closeMenu: this.close,
      focusAnchor: this.focus
    })));
  }

}

exports.default = AnchoredMenu;
AnchoredMenu.defaultProps = {
  popoverProps: {},
  onArrowKey: () => {},
  onEnter: () => {},
  onOpen: () => {},
  onClose: () => {}
};
AnchoredMenu.propTypes = {
  renderAnchor: _propTypes.default.func.isRequired,
  onOpen: _propTypes.default.func,
  onClose: _propTypes.default.func,
  onArrowKey: _propTypes.default.func,
  onEnter: _propTypes.default.func,
  popoverProps: _propTypes.default.shape(),
  renderMenu: _propTypes.default.func.isRequired
};