"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _button = _interopRequireDefault(require("../button/button"));

var _DropdownOption = _interopRequireDefault(require("./DropdownOption"));

var _badge = _interopRequireDefault(require("../badge/badge"));

var _AnchoredMenu = _interopRequireDefault(require("./AnchoredMenu"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const block = 'drop-down';

class Dropdown extends _react.default.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      highlightedIndex: -1
    });

    _defineProperty(this, "isSelected", value => [].concat(this.props.selectedValue).indexOf(value) !== -1);

    _defineProperty(this, "handleMouseEnterOption", hoveredOption => {
      const {
        options
      } = this.props;
      this.setState({
        highlightedIndex: options.findIndex((_ref) => {
          let {
            value
          } = _ref;
          return value === hoveredOption;
        })
      });
    });

    _defineProperty(this, "handleMouseLeaveOption", () => {
      this.setState({
        highlightedIndex: -1
      });
    });

    _defineProperty(this, "handleClose", () => {
      if (!this.props.multiple) {
        this.setState({
          highlightedIndex: this.props.options.findIndex((_ref2) => {
            let {
              value
            } = _ref2;
            return value === this.props.selectedValue;
          })
        });
      }
    });

    _defineProperty(this, "handleArrowKey", arrowKey => {
      const {
        options
      } = this.props;
      const direction = arrowKey === 'ArrowUp' ? -1 : 1;
      const newHighlightedIndex = (options.length + // Using max(-1, newIndex) to cover for case with arrowUp from initial index -1 state
      Math.max(-1, this.state.highlightedIndex + direction)) % options.length;
      this.setState({
        highlightedIndex: newHighlightedIndex
      });
    });

    _defineProperty(this, "handleValueToggled", toggledValue => {
      const value = this.props.selectedValue || [];
      const toggledValueIndex = value.indexOf(toggledValue);
      this.props.onChange(toggledValueIndex === -1 ? [...value, toggledValue] : [...value.slice(0, toggledValueIndex), ...value.slice(toggledValueIndex + 1)]);
    });

    _defineProperty(this, "handleSelection", (value, _ref3) => {
      let {
        closeMenu,
        focusAnchor
      } = _ref3;
      const {
        multiple,
        onChange
      } = this.props;
      focusAnchor();

      if (multiple) {
        this.handleValueToggled(value);
      } else {
        onChange(value);
        closeMenu();
      }
    });

    _defineProperty(this, "handleEnter", (event, actions) => {
      const highlightedOption = this.props.options[this.state.highlightedIndex];

      if (highlightedOption) {
        event.preventDefault();
        this.handleSelection(highlightedOption.value, actions);
      }
    });

    _defineProperty(this, "renderButton", (onClick, ref, isOpen) => {
      const {
        placeholder,
        selectedValue,
        multiple,
        type
      } = this.props;
      const selected = multiple ? selectedValue && selectedValue.length > 0 : selectedValue !== null;
      return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_button.default, {
        className: `${block}__button ${type}`,
        icon: isOpen || this.props.showOptionsAbove ? 'chevron_up' : 'chevron_down',
        disabled: this.props.disabled,
        onClick: onClick,
        rightAlignedIcon: true,
        ref: ref,
        type: this.props.type
      }, this.resolveLabel()), type === 'ghost' && placeholder && /*#__PURE__*/_react.default.createElement("label", {
        className: `drop-down__label ${selected && 'selected'}`
      }, placeholder));
    });

    _defineProperty(this, "renderOption", (option, highlighted, onClick, onMouseEnter) => /*#__PURE__*/_react.default.createElement(_DropdownOption.default, {
      key: option.value,
      value: option.value,
      label: option.label,
      isSelected: this.isSelected(option.value),
      isHighlighted: highlighted,
      onSelect: onClick,
      onMouseEnter: onMouseEnter
    }));
  }

  resolveLabel() {
    const {
      selectedValue,
      placeholder,
      options,
      multiple,
      type
    } = this.props;

    if (selectedValue === null || multiple && selectedValue.length === 0) {
      return type === 'ghost' ? ' ' : placeholder;
    }

    if (multiple) {
      return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, selectedValue.map(v => {
        const option = options.find(o => o.value === v);
        return /*#__PURE__*/_react.default.createElement(_badge.default, {
          key: option.label + option.value,
          className: `${block}__badge`,
          icon: "remove",
          onIconClick: event => {
            event.stopPropagation();
            this.handleValueToggled(option.value);
          },
          rightAlignedIcon: true
        }, option.label);
      }));
    }

    const selectedOption = options.find(option => option.value === selectedValue);
    return selectedOption ? selectedOption.label : placeholder;
  }

  render() {
    const {
      highlightedIndex
    } = this.state;
    const {
      options,
      showOptionsAbove,
      className,
      renderButton,
      renderOption,
      popoverProps,
      type,
      placeholder
    } = this.props;
    return /*#__PURE__*/_react.default.createElement(_AnchoredMenu.default, {
      renderAnchor: renderButton || this.renderButton,
      renderMenu: actions => options.map((option, index) => (renderOption || this.renderOption)(option, highlightedIndex === index, () => this.handleSelection(option.value, actions), () => this.handleMouseEnterOption(option.value))),
      onArrowKey: this.handleArrowKey,
      onClose: this.handleClose,
      onEnter: this.handleEnter,
      popoverProps: _objectSpread({
        contentClassName: `${block}__popover`,
        withoutArrow: true,
        down: !showOptionsAbove,
        dynamicAnchorNode: true
      }, popoverProps),
      className: (0, _classnames.default)(block, className, type === 'ghost' && placeholder && 'margin'),
      onMouseLeave: this.handleMouseLeaveOption
    });
  }

}

Dropdown.defaultProps = {
  className: '',
  multiple: false,
  onChange: () => {},
  renderButton: null,
  renderOption: null,
  popoverProps: {},
  options: [],
  placeholder: '',
  disabled: false,
  selectedValue: null,
  showOptionsAbove: false,
  type: 'default'
};
Dropdown.propTypes = {
  className: _propTypes.default.string,
  multiple: _propTypes.default.bool,
  onChange: _propTypes.default.func,
  renderButton: _propTypes.default.func,
  renderOption: _propTypes.default.func,
  disabled: _propTypes.default.bool,
  options: _propTypes.default.arrayOf(_propTypes.default.shape({
    label: _propTypes.default.string.isRequired,
    value: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.bool, _propTypes.default.string])
  })),
  placeholder: _propTypes.default.string,
  selectedValue: _propTypes.default.oneOfType([_propTypes.default.arrayOf(_propTypes.default.oneOfType([_propTypes.default.bool, _propTypes.default.number, _propTypes.default.string])), _propTypes.default.bool, _propTypes.default.number, _propTypes.default.string]),
  showOptionsAbove: _propTypes.default.bool,
  type: _propTypes.default.oneOf(['default', 'ghost']),
  popoverProps: _propTypes.default.shape()
};
var _default = Dropdown;
exports.default = _default;