"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _customShapes = _interopRequireDefault(require("../../utils/customShapes"));

var _standardShapes = _interopRequireDefault(require("../../utils/standardShapes"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const Icon = (_ref) => {
  let {
    className,
    size,
    shape,
    small,
    type,
    onClick
  } = _ref;
  const iconClasses = (0, _classnames.default)(className, 'icon', `icon--${type}`);
  let svgPath;
  let specificSize = size;
  let viewBoxSize = size;
  const sizes = {
    small: '18',
    medium: '24',
    large: '30'
  };

  if (_standardShapes.default[shape]) {
    const isSmall = small || size === 'small';
    const pathType = isSmall ? 'smallPath' : 'largePath';
    svgPath = _standardShapes.default[shape][pathType] || _standardShapes.default[shape].path;
    viewBoxSize = isSmall ? '18' : '24';
    if (sizes[size]) specificSize = sizes[size];
  } else if (_customShapes.default[shape]) {
    svgPath = _customShapes.default[shape].path;
    viewBoxSize = _customShapes.default[shape].viewPort;
  } else {
    return null;
  }

  return /*#__PURE__*/_react.default.createElement("svg", {
    className: iconClasses,
    dangerouslySetInnerHTML: {
      __html: svgPath
    } // eslint-disable-line react/no-danger
    ,
    height: specificSize || viewBoxSize,
    onClick: onClick,
    viewBox: `0 0 ${viewBoxSize} ${viewBoxSize}`,
    width: specificSize || viewBoxSize
  });
};

Icon.propTypes = {
  className: _propTypes.default.string,
  shape: _propTypes.default.string.isRequired,
  size: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string]),
  small: _propTypes.default.bool,
  type: _propTypes.default.string,
  onClick: _propTypes.default.func
};
Icon.defaultProps = {
  className: '',
  size: null,
  small: false,
  type: 'default',
  onClick: () => {}
};
Icon.propDescriptions = {
  className: 'Any combination of CSS class names',
  shape: 'Any of the icons listed above',
  size: 'Send a string with "small", "medium" or "large" or specify exact size of the icon in number of pixels.',
  small: '(DEPRECATED) Make the size one of the pre-defined ones'
};
var _default = Icon;
exports.default = _default;