"use strict";

var _react = _interopRequireDefault(require("react"));

var _sinon = _interopRequireDefault(require("sinon"));

var _chai = require("chai");

var _enzyme = require("enzyme");

var _icon = _interopRequireDefault(require("./../icon"));

var _standardShapes = _interopRequireDefault(require("../../../utils/standardShapes"));

var _customShapes = _interopRequireDefault(require("../../../utils/customShapes"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Icon', () => {
  it('should render an icon', () => {
    const icon = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_icon.default, {
      shape: "add"
    }));
    (0, _chai.expect)(icon.find('svg')).to.be.present();
  });
  it('should set width and height of the svg if specified', () => {
    const icon = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_icon.default, {
      shape: "add",
      size: 1337
    }));
    (0, _chai.expect)(icon.find('svg')).to.be.present();
    (0, _chai.expect)(icon.find('svg')).to.have.attr('width', '1337');
    (0, _chai.expect)(icon.find('svg')).to.have.attr('height', '1337');
  });
  it('should render the large version of standard shapes by default', () => {
    const icon = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_icon.default, {
      shape: "add"
    }));
    (0, _chai.expect)(icon.find('svg')).to.have.attr('viewBox', '0 0 24 24');
  });
  it('should render the small version of standard shapes when the small prop is set', () => {
    const icon = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_icon.default, {
      shape: "add",
      small: true
    }));
    (0, _chai.expect)(icon.find('svg')).to.have.attr('viewBox', '0 0 18 18');
  });
  it('should render custom shapes', () => {
    const icon = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_icon.default, {
      shape: "logo"
    }));
    (0, _chai.expect)(icon.find('svg')).to.be.present();
  });
  it('should not render undefined shapes', () => {
    const icon = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_icon.default, {
      shape: "DOES_NOT_EXIST"
    }));
    (0, _chai.expect)(icon.find('svg')).to.not.be.present();
  });
  it('should render regular size icons for all standard shapes', () => {
    Object.keys(_standardShapes.default).forEach(shapeName => {
      const icon = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_icon.default, {
        shape: shapeName
      }));
      (0, _chai.expect)(icon.find('svg')).to.be.present();
    });
  });
  it('should render small size icons for all standard shapes', () => {
    Object.keys(_standardShapes.default).forEach(shapeName => {
      const icon = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_icon.default, {
        shape: shapeName,
        small: true
      }));
      (0, _chai.expect)(icon.find('svg')).to.be.present();
    });
  });
  it('should call a given onClick handler on being clicked', () => {
    const onClickStub = _sinon.default.stub();

    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_icon.default, {
      shape: "remove",
      onClick: onClickStub
    }));
    wrapper.simulate('click');
    (0, _chai.expect)(onClickStub).to.have.been.calledOnce();
  });
  describe('Custom shapes', () => {
    it('should render icons for all custom shapes', () => {
      Object.keys(_customShapes.default).forEach(shapeName => {
        const icon = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_icon.default, {
          shape: shapeName
        }));
        (0, _chai.expect)(icon.find('svg')).to.be.present();
      });
    });
  });
});