"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactDom = require("react-dom");

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _button = _interopRequireDefault(require("../button/button"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const Wrapper = _styledComponents.default.div.withConfig({
  displayName: "mediaSlider__Wrapper",
  componentId: "sc-7vhfqf-0"
})(["&:focus{outline:none;}"]);

const ThumbnailWrapper = _styledComponents.default.div.withConfig({
  displayName: "mediaSlider__ThumbnailWrapper",
  componentId: "sc-7vhfqf-1"
})(["display:flex;"]);

const Thumbnails = _styledComponents.default.div.withConfig({
  displayName: "mediaSlider__Thumbnails",
  componentId: "sc-7vhfqf-2"
})(["display:-webkit-box;flex:1;overflow:hidden;overflow-x:auto;"]);

const MediaSlider = (_ref) => {
  let {
    items,
    activeIndex,
    onActiveIndexChange,
    renderPreview,
    renderThumbnail
  } = _ref;
  const selectedItem = (0, _react.useRef)(null);

  const move = direction => {
    const newActiveIndex = (activeIndex + direction + items.length) % items.length;
    onActiveIndexChange(newActiveIndex);
    setTimeout(() => {
      if (selectedItem.current) {
        // eslint-disable-next-line react/no-find-dom-node
        (0, _reactDom.findDOMNode)(selectedItem.current).scrollIntoViewIfNeeded(false);
      }
    });
  };

  const goRight = () => move(1);

  const goLeft = () => move(-1);

  const handleNavigation = e => {
    switch (e.key) {
      case 'ArrowRight':
        e.preventDefault();
        goRight();
        break;

      case 'ArrowLeft':
        e.preventDefault();
        goLeft();
        break;

      default:
        break;
    }
  };

  return /*#__PURE__*/_react.default.createElement(Wrapper, {
    onKeyDown: handleNavigation,
    tabIndex: -1
  }, renderPreview(items[activeIndex]), /*#__PURE__*/_react.default.createElement(ThumbnailWrapper, null, items.length > 1 && /*#__PURE__*/_react.default.createElement(_button.default, {
    className: "go-left",
    type: "ghost",
    onClick: goLeft,
    icon: "chevron_left"
  }), /*#__PURE__*/_react.default.createElement(Thumbnails, null, items.map((thumb, index) => renderThumbnail(thumb, {
    isActive: activeIndex === index,
    ref: activeIndex === index ? selectedItem : undefined,
    index,
    onClick: () => move(index - activeIndex)
  }))), items.length > 1 && /*#__PURE__*/_react.default.createElement(_button.default, {
    className: "go-right",
    type: "ghost",
    onClick: goRight,
    icon: "chevron_right"
  })));
};

MediaSlider.propTypes = {
  items: _propTypes.default.arrayOf(_propTypes.default.shape({
    id: _propTypes.default.string.isRequired
  })).isRequired,
  activeIndex: _propTypes.default.number.isRequired,
  onActiveIndexChange: _propTypes.default.func.isRequired,
  renderPreview: _propTypes.default.func.isRequired,
  renderThumbnail: _propTypes.default.func.isRequired
};
MediaSlider.defaultProps = {};
MediaSlider.propDescriptions = {
  items: 'Array of objects.',
  onActiveIndexChange: 'A function that expects an index as argument.',
  renderPreview: `media => <React.Element/>`,
  renderThumbnail: `(media, thumbnailProps) => <div {...thumbnailProps}><img src={media.src} /></div>`,
  onFocus: 'Is called when component is natively focused.',
  onBlur: 'Is called when component is natively blurred.'
};
var _default = MediaSlider;
exports.default = _default;