"use strict";

var _react = _interopRequireDefault(require("react"));

var _sinon = _interopRequireDefault(require("sinon"));

var _chai = require("chai");

var _enzyme = require("enzyme");

var _mediaSlider = _interopRequireDefault(require("../mediaSlider"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function mountMediaSlider(overrideProps) {
  const mediaArray = [{
    id: 'first-image',
    imageSrc: 'https://placebear.com/432/243',
    thumbSrc: 'https://placebear.com/432/243',
    youtube: 'https://www.youtube.com/embed/2HH4CiAjjvM'
  }, {
    id: 'second-image',
    imageSrc: 'https://placebear.com/100/234',
    thumbSrc: 'https://placebear.com/100/234'
  }, {
    id: 'third-image',
    imageSrc: 'https://placebear.com/400/225',
    thumbSrc: 'https://placebear.com/400/225'
  }];
  const defaultProps = {
    items: mediaArray,
    activeIndex: 0,
    updateActiveIndex: () => {},
    renderPreview: () => /*#__PURE__*/_react.default.createElement("div", {
      className: "preview"
    }),
    renderThumbnail: (thumb, thumbnailProps) => /*#__PURE__*/_react.default.createElement("div", _extends({
      className: "thumb"
    }, thumbnailProps))
  };
  return (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_mediaSlider.default, _extends({}, defaultProps, overrideProps)));
}

describe('Media slider', () => {
  it('should render with one item in it', () => {
    const mediaSlider = mountMediaSlider();
    (0, _chai.expect)(mediaSlider.find('.preview').length).to.equal(1);
  });
  it('should render with three thumbnails in it', () => {
    const mediaSlider = mountMediaSlider();
    (0, _chai.expect)(mediaSlider.find('.thumb').length).to.equal(3);
  });
  it('should render with a image for each slide', () => {
    const mediaSlider = mountMediaSlider({
      renderPreview: media => /*#__PURE__*/_react.default.createElement("img", {
        src: media.imageSrc
      })
    });
    (0, _chai.expect)(mediaSlider.find('img').length).to.equal(1);
  });
  it('should render with chevron on each side', () => {
    const mediaSlider = mountMediaSlider({
      activeIndex: 1
    });
    (0, _chai.expect)(mediaSlider.find('.go-left button').length).to.equal(1);
    (0, _chai.expect)(mediaSlider.find('.go-right button').length).to.equal(1);
  });
  it('should slide to next slide when right chevron is clicked', () => {
    const updateActiveIndex = _sinon.default.spy();

    const mediaSlider = mountMediaSlider({
      activeIndex: 1,
      onActiveIndexChange: updateActiveIndex
    });
    mediaSlider.find('.go-right button').simulate('click');
    (0, _chai.expect)(updateActiveIndex).to.have.been.called.with(2);
  });
  it('should slide to previous slide when left chevron is clicked', () => {
    const updateActiveIndex = _sinon.default.spy();

    const mediaSlider = mountMediaSlider({
      activeIndex: 2,
      onActiveIndexChange: updateActiveIndex
    });
    mediaSlider.find('.go-left button').simulate('click');
    (0, _chai.expect)(updateActiveIndex).to.have.been.called.with(1);
  });
  it('should slide to last slide when last thumbnail is clicked', () => {
    const updateActiveIndex = _sinon.default.spy();

    const mediaSlider = mountMediaSlider({
      onActiveIndexChange: updateActiveIndex
    });
    mediaSlider.find('.thumb').last().simulate('click');
    (0, _chai.expect)(updateActiveIndex).to.have.been.called.with(2);
  });
});