"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _notification = _interopRequireDefault(require("../notification/notification"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const componentClassName = 'klara-ui-modal';

class Modal extends _react.default.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "onContainerClick", (_ref) => {
      let {
        target
      } = _ref;

      if (target === this.containerRef.current) {
        this.props.onClose();
      }
    });

    _defineProperty(this, "onKeyUp", (_ref2) => {
      let {
        key
      } = _ref2;

      if (key === 'Escape') {
        this.props.onClose();
      }
    });

    _defineProperty(this, "containerRef", /*#__PURE__*/_react.default.createRef());
  }

  componentDidMount() {
    window.addEventListener('keyup', this.onKeyUp);
  }

  componentWillUnmount() {
    window.removeEventListener('keyup', this.onKeyUp);
  }

  render() {
    const {
      children,
      title,
      notification,
      renderHeader,
      renderFooter,
      onDismissNotification,
      className
    } = this.props;
    return /*#__PURE__*/_react.default.createElement("div", {
      className: (0, _classnames.default)(componentClassName, className),
      onClick: this.onContainerClick,
      ref: this.containerRef
    }, /*#__PURE__*/_react.default.createElement("div", {
      className: `${componentClassName}__container`
    }, /*#__PURE__*/_react.default.createElement("header", null, renderHeader(title, `${componentClassName}__title`)), /*#__PURE__*/_react.default.createElement("div", {
      className: `${componentClassName}__content`
    }, children), /*#__PURE__*/_react.default.createElement("div", {
      className: `${componentClassName}__notifications`
    }, notification && /*#__PURE__*/_react.default.createElement(_notification.default, {
      dismissable: notification.dismissable,
      onDismiss: onDismissNotification,
      title: notification.title,
      description: notification.description || '',
      type: notification.type
    })), renderFooter && /*#__PURE__*/_react.default.createElement("footer", null, renderFooter())));
  }

}

Modal.propTypes = {
  children: _propTypes.default.oneOfType([_propTypes.default.arrayOf(_propTypes.default.node), _propTypes.default.node]).isRequired,
  title: _propTypes.default.string.isRequired,
  className: _propTypes.default.string,
  renderHeader: _propTypes.default.func,
  notification: _propTypes.default.shape({
    dismissable: _propTypes.default.bool,
    title: _propTypes.default.string,
    description: _propTypes.default.description,
    type: _propTypes.default.string
  }),
  onDismissNotification: _propTypes.default.func,
  onClose: _propTypes.default.func,
  renderFooter: _propTypes.default.func
};
Modal.defaultProps = {
  notification: null,
  renderHeader: (title, suggestedClassName) => /*#__PURE__*/_react.default.createElement("h2", {
    className: suggestedClassName
  }, title),
  onClose: () => {},
  onDismissNotification: () => {},
  className: '',
  renderFooter: null
};
Modal.propDescriptions = {
  notification: 'An object with the properties dismissable, title, description and type',
  onClose: 'Fires on pressing Escape, or when clicking outside the modal',
  renderFooter: 'A function that returns JSX'
};
var _default = Modal;
exports.default = _default;