"use strict";

var _react = _interopRequireDefault(require("react"));

var _sinon = _interopRequireDefault(require("sinon"));

var _chai = require("chai");

var _enzyme = require("enzyme");

var _modal = _interopRequireDefault(require("./../modal"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Modal', () => {
  it('should render', () => {
    const modal = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_modal.default, {
      title: "Hello"
    }, /*#__PURE__*/_react.default.createElement("div", null, "Content")));
    (0, _chai.expect)(modal).to.have.className('klara-ui-modal');
    (0, _chai.expect)(modal.text()).to.have.string('Hello');
    (0, _chai.expect)(modal.text()).to.have.string('Content');
  });
  it('should support a custom footer', () => {
    const modal = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_modal.default, {
      title: "Hello",
      renderFooter: () => /*#__PURE__*/_react.default.createElement("div", null, "Footer")
    }, /*#__PURE__*/_react.default.createElement("div", null, "Content")));
    (0, _chai.expect)(modal.text()).to.have.string('Footer');
  });
  it('should support notifications', () => {
    const modal = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_modal.default, {
      title: "Hello",
      notification: {
        title: 'Hello World!'
      }
    }, /*#__PURE__*/_react.default.createElement("div", null, "Content")));
    (0, _chai.expect)(modal.text()).to.have.string('Hello World!');
  });
  it('should close on pressing Escape', () => {
    const onClose = _sinon.default.spy();

    const modal = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_modal.default, {
      title: "Hello",
      onClose: onClose
    }, /*#__PURE__*/_react.default.createElement("div", null, "Content")));
    modal.instance().onKeyUp({
      key: 'Escape'
    });
    modal.instance().onKeyUp({
      key: 'Control'
    });
    modal.instance().onKeyUp({
      key: 'Alt'
    });
    modal.instance().onKeyUp({
      key: 'Backspace'
    });
    (0, _chai.expect)(onClose).to.have.been.calledOnce();
  });
  it('should close on clicking outside the container', () => {
    const onClose = _sinon.default.spy();

    const modal = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_modal.default, {
      title: "Hello",
      onClose: onClose
    }, /*#__PURE__*/_react.default.createElement("div", null, "Content")));
    modal.find('.klara-ui-modal__container').simulate('click');
    modal.find('.klara-ui-modal').simulate('click');
    (0, _chai.expect)(onClose).to.have.been.calledOnce();
  });
});