"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _button = _interopRequireDefault(require("../button/button"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class Notification extends _react.default.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "onDismiss", () => {
      this.setState({
        hidden: true
      }); // CSS transition has a duration of 500ms.

      this.dismissTransitionTimeout = setTimeout(() => {
        this.props.onDismiss();
      }, 500);
    });

    _defineProperty(this, "countdownTick", () => {
      const {
        secondsLeft
      } = this.state;

      if (secondsLeft > 0) {
        this.setState({
          secondsLeft: secondsLeft - 1
        });
        this.countdownTimer = setTimeout(this.countdownTick, 1000);
      } else {
        this.onDismiss();
      }
    });

    this.countdownTimer = null;
    this.startAnimationTimer = null;
    this.state = {
      hidden: true,
      secondsLeft: Math.ceil(props.dismissTimeout)
    };
  }

  componentDidMount() {
    this.startAnimationTimer = setTimeout(() => {
      this.setState({
        hidden: false
      });
      const {
        dismissable,
        dismissTimeout
      } = this.props;

      if (!dismissable && dismissTimeout) {
        this.countdownTick();
      }
    }, 50);
  }

  componentWillUnmount() {
    clearTimeout(this.dismissTransitionTimeout);
    clearTimeout(this.countdownTimer);
    clearTimeout(this.startAnimationTimer);
  }

  render() {
    const {
      hidden,
      secondsLeft
    } = this.state;
    const {
      title,
      description,
      dismissable,
      type,
      overlay,
      buttons,
      showCountdown
    } = this.props;
    const classes = (0, _classnames.default)('notification', `notification--${type}`, {
      'notification--hidden': hidden,
      'notification--showing': !hidden,
      'notification--overlay': overlay,
      'notification--non-overlay': !overlay
    });
    /* eslint-disable no-irregular-whitespace */

    return /*#__PURE__*/_react.default.createElement("div", {
      className: classes
    }, /*#__PURE__*/_react.default.createElement("div", {
      className: "notification__inner"
    }, /*#__PURE__*/_react.default.createElement("div", {
      className: "notification__body"
    }, /*#__PURE__*/_react.default.createElement("strong", null, title), description && ` – ${description}`, showCountdown && /*#__PURE__*/_react.default.createElement("span", {
      className: "notification__countdown-value"
    }, secondsLeft)), buttons && buttons.map(button => /*#__PURE__*/_react.default.createElement(_button.default, {
      key: button.label,
      type: "inverted",
      onClick: () => {
        button.action(this.onDismiss);
      }
    }, button.label)), dismissable && /*#__PURE__*/_react.default.createElement(_button.default, {
      type: "inverted",
      onClick: this.onDismiss
    }, "Avf\xE4rda")));
  }

}

exports.default = Notification;

_defineProperty(Notification, "propTypes", {
  buttons: _propTypes.default.arrayOf(_propTypes.default.shape({
    label: _propTypes.default.string.isRequired,
    action: _propTypes.default.func.isRequired
  })),
  description: _propTypes.default.string,
  dismissable: _propTypes.default.bool,
  dismissTimeout: _propTypes.default.number,
  onDismiss: _propTypes.default.func,
  overlay: _propTypes.default.bool,
  showCountdown: _propTypes.default.bool,
  title: _propTypes.default.string.isRequired,
  type: _propTypes.default.oneOf(['danger', 'info', 'success'])
});

_defineProperty(Notification, "defaultProps", {
  dismissable: false,
  dismissTimeout: 5,
  onDismiss: () => {},
  overlay: false,
  showCountdown: false,
  type: 'danger',
  description: '',
  buttons: []
});

_defineProperty(Notification, "propDescriptions", {
  buttons: 'A list of custom buttons. Each action callback will receive the dismiss function for actually dismissing the notification. Fields: label (string), action (callback function)',
  overlay: 'Render the notification "on top of" it\'s parent',
  type: 'Allowed values are "info", "danger", and "success"',
  dismissable: 'Makes it possible for the user to manually dismiss this notification',
  showCountdown: 'Visually give the user feedback of how much longer this notification will show',
  onDismiss: 'Function that will be called as the notification is dismissed',
  dismissTimeout: 'A number which indicates the amount of seconds to show this notification before dismissing it. Set this to 0 to make the notification infinite.'
});