"use strict";

var _react = _interopRequireDefault(require("react"));

var _sinon = _interopRequireDefault(require("sinon"));

var _chai = require("chai");

var _enzyme = require("enzyme");

var _notification = _interopRequireDefault(require("../notification"));

var _button = _interopRequireDefault(require("../../button/button"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Notification', () => {
  let clock;
  before(() => {
    clock = _sinon.default.useFakeTimers();

    global.requestAnimationFrame = cb => {
      cb();
    };
  });
  after(() => {
    clock.restore();
  });
  it('should mount', () => {
    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_notification.default, {
      title: "Notification"
    }));
    (0, _chai.expect)(wrapper).to.be.present();
  });
  it('should render with the given title and description', () => {
    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_notification.default, {
      title: "This is the title",
      description: "This is the description"
    }));
    (0, _chai.expect)(wrapper.text()).to.contain('This is the title');
    (0, _chai.expect)(wrapper.text()).to.contain('This is the description');
  });
  it('should render with a set of custom buttons', () => {
    const firstStub = _sinon.default.stub();

    const secondStub = _sinon.default.stub();

    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_notification.default, {
      title: "This is the title",
      buttons: [{
        label: 'First Button',
        action: firstStub
      }, {
        label: 'Second Button',
        action: secondStub
      }]
    }));
    wrapper.find(_button.default).filterWhere(btn => btn.text() === 'First Button').simulate('click');
    (0, _chai.expect)(firstStub).to.have.been.calledOnce();
    wrapper.find(_button.default).filterWhere(btn => btn.text() === 'Second Button').simulate('click');
    (0, _chai.expect)(firstStub).to.have.been.calledOnce();
  });
  it('call the given onDismiss when automatically dismissing', () => {
    const onDismissStub = _sinon.default.stub();

    (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_notification.default, {
      title: "This is the title",
      dismissTimeout: 1,
      onDismiss: onDismissStub
    })); // 50ms for initial mount timeout, 1000ms to the first tick, 500ms for the CSS transition delay.

    clock.tick(1551);
    (0, _chai.expect)(onDismissStub).to.have.been.calledOnce();
  });
});