"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactDom = require("react-dom");

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactOutsideClickHandler = _interopRequireDefault(require("react-outside-click-handler"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const TRIANGLE_HEIGHT = 6;
const TRIANGLE_WIDTH = 12;

class Popover extends _react.default.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      contentSize: null,
      anchorPoint: this.props.anchorNode ? this.getAnchorPointFromNode() : null
    });

    _defineProperty(this, "setContentRef", ref => {
      this.contentRef = ref;
    });

    _defineProperty(this, "handleOutsideClick", e => {
      if (!this.props.onOutsideClick) return;
      if (this.openedBy.contains(e.target)) return;
      this.props.onOutsideClick();
    });
  }

  componentDidMount() {
    this.setState({
      contentSize: this.getContentSize()
    });
    this.openedBy = document.activeElement;
  } // eslint-disable-next-line camelcase


  UNSAFE_componentWillReceiveProps(_ref) {
    let {
      dynamicAnchorNode,
      dynamicContent
    } = _ref;

    if (dynamicAnchorNode || dynamicContent) {
      this.setState({
        needsRecalculation: true
      });
    }
  }

  componentDidUpdate() {
    const {
      dynamicAnchorNode,
      dynamicContent
    } = this.props;
    const {
      needsRecalculation,
      anchorPoint,
      contentSize
    } = this.state;

    if (needsRecalculation) {
      this.setState({
        anchorPoint: dynamicAnchorNode ? this.getAnchorPointFromNode() : anchorPoint,
        contentSize: dynamicContent ? this.getContentSize() : contentSize,
        needsRecalculation: false
      });
    }
  }

  getContentSize() {
    const {
      left,
      right
    } = this.props;
    const {
      width,
      height
    } = this.contentRef.getBoundingClientRect();
    return left || right ? height : width;
  }

  getPositionForAxis(node) {
    const {
      min,
      max,
      left,
      right
    } = this.props;
    const anchorStart = left || right ? node.offsetTop : node.offsetLeft;
    const anchorSize = left || right ? node.offsetHeight : node.offsetWidth;
    return Math.min(max - TRIANGLE_WIDTH, Math.max(min + TRIANGLE_WIDTH, anchorStart + anchorSize / 2));
  }

  getAnchorPointFromNode() {
    const {
      anchorNode,
      right,
      down,
      left
    } = this.props;
    const node = (0, _reactDom.findDOMNode)(anchorNode); // eslint-disable-line react/no-find-dom-node

    const axisPosition = this.getPositionForAxis(node);
    return left ? {
      top: axisPosition,
      left: node.offsetLeft
    } : right ? {
      top: axisPosition,
      left: node.offsetLeft + node.offsetWidth
    } : down ? {
      left: axisPosition,
      top: node.offsetTop + node.offsetHeight
    } : // upward
    {
      left: axisPosition,
      top: node.offsetTop
    };
  }

  render() {
    const {
      children,
      className,
      contentClassName,
      min,
      max,
      down,
      left,
      right,
      withoutArrow
    } = this.props;
    const anchorPoint = this.props.anchorPoint || this.state.anchorPoint;
    const contentSize = this.state.contentSize;
    const absoluteDirection = right ? 'left' : left ? 'right' : down ? 'top' : 'bottom';
    const contentStyle = {
      [absoluteDirection]: TRIANGLE_HEIGHT
    };
    const positionAdjustmentProperty = left || right ? 'top' : 'left';

    if (contentSize) {
      const requiredLeadingAdjustment = Math.max(0, min + contentSize / 2 - anchorPoint[positionAdjustmentProperty]);
      const requiredTrailingAdjustment = Math.max(0, anchorPoint[positionAdjustmentProperty] + contentSize / 2 - max);
      Object.assign(contentStyle, {
        [positionAdjustmentProperty]: -contentSize / 2 + requiredLeadingAdjustment - requiredTrailingAdjustment
      });
    }

    return /*#__PURE__*/_react.default.createElement(_reactOutsideClickHandler.default, {
      onOutsideClick: this.handleOutsideClick
    }, /*#__PURE__*/_react.default.createElement("div", {
      className: `klara-ui-popover ${className}`,
      style: {
        left: anchorPoint.left,
        top: anchorPoint.top,
        [left || right ? 'height' : 'width']: '100%'
      }
    }, /*#__PURE__*/_react.default.createElement("div", {
      ref: this.setContentRef,
      style: contentStyle,
      className: `klara-ui-popover__content ${contentClassName}`
    }, children), !withoutArrow && /*#__PURE__*/_react.default.createElement("div", {
      className: "klara-ui-popover__attach-arrow",
      style: {
        [absoluteDirection]: 0,
        [positionAdjustmentProperty]: -TRIANGLE_HEIGHT,
        transform: `rotate(${right ? 135 : left ? 315 : down ? 225 : 45}deg)`
      }
    })));
  }

}

exports.default = Popover;

_defineProperty(Popover, "propTypes", {
  withoutArrow: _propTypes.default.bool,
  anchorPoint: _propTypes.default.shape({
    left: _propTypes.default.number.isRequired,
    top: _propTypes.default.number.isRequired
  }),
  anchorNode: _propTypes.default.oneOfType([_propTypes.default.instanceOf(HTMLElement), _propTypes.default.instanceOf(_react.default.Component)]),
  children: _propTypes.default.node.isRequired,
  className: _propTypes.default.string,
  contentClassName: _propTypes.default.string,
  min: _propTypes.default.number,
  dynamicAnchorNode: _propTypes.default.bool,
  dynamicContent: _propTypes.default.bool,
  max: _propTypes.default.number,
  down: _propTypes.default.bool,
  left: _propTypes.default.bool,
  right: _propTypes.default.bool,
  onOutsideClick: _propTypes.default.func
});

_defineProperty(Popover, "propDescriptions", {
  onOutsideClick: 'Provide a function that decides what happens if you click outside the popover, i.e. togglePopover'
});

_defineProperty(Popover, "defaultProps", {
  withoutArrow: false,
  anchorPoint: null,
  dynamicAnchorNode: false,
  dynamicContent: false,
  className: '',
  contentClassName: '',
  down: false,
  anchorNode: null,
  left: false,
  right: false,
  min: Number.MIN_SAFE_INTEGER,
  max: Number.MAX_SAFE_INTEGER,
  onOutsideClick: null
});