"use strict";

var _react = _interopRequireDefault(require("react"));

var _chai = require("chai");

var _enzyme = require("enzyme");

var _sinon = _interopRequireDefault(require("sinon"));

var _radiobuttons = _interopRequireDefault(require("./radiobuttons"));

var _icon = _interopRequireDefault(require("../icon/icon"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const propEquals = (prop, value) => node => node.prop(prop) === value;

const options = [{
  label: 'First Option',
  value: 'one'
}, {
  label: 'Second Option',
  value: 'two'
}, {
  label: 'Third Option',
  value: 'three'
}, {
  label: 'Fourth Option',
  value: 'four'
}];
describe('Radiobuttons', () => {
  it('should mount', () => {
    (0, _chai.expect)((0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_radiobuttons.default, {
      options: options
    }))).to.exist();
  });
  it('should not select an option by default', () => {
    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_radiobuttons.default, {
      options: options
    }));
    (0, _chai.expect)(wrapper.find(_icon.default).filterWhere(propEquals('shape', 'radio_selected'))).to.not.exist();
  });
  it('should select the matching option if given a value', () => {
    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_radiobuttons.default, {
      selected: "one",
      options: options
    }));
    (0, _chai.expect)(wrapper.find(_icon.default).filterWhere(propEquals('shape', 'radio_selected')).parents().first().text()).to.equal('First Option');
  });
  it('should call the onChange handler when clicking one of the options', () => {
    const onChangeStub = _sinon.default.stub();

    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_radiobuttons.default, {
      onChange: onChangeStub,
      options: options
    }));
    wrapper.find('.kui-radiobuttons__option').first().simulate('click');
    (0, _chai.expect)(onChangeStub).to.have.been.called();
  });
});