"use strict";

var _react = _interopRequireDefault(require("react"));

var _chai = require("chai");

var _enzyme = require("enzyme");

var _sinon = _interopRequireDefault(require("sinon"));

var _spinner = _interopRequireDefault(require("../spinner"));

var _icon = _interopRequireDefault(require("../../icon/icon"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const now = 1516627620000; // 2018-01-22 14:27.00 UTC+1

describe('Spinner', () => {
  let clock;
  beforeEach(() => {
    clock = _sinon.default.useFakeTimers(now);
  });
  afterEach(() => {
    clock.restore();
  });
  it('should render a spinner', () => {
    const spinner = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_spinner.default, null));
    (0, _chai.expect)(spinner.find(_icon.default).hasClass('spinner--robot')).to.equal(true);
  });
  it('should render a fading spinner when receiving the "fading" type', () => {
    const spinner = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_spinner.default, {
      type: "fading"
    }));
    (0, _chai.expect)(spinner.find(_icon.default).hasClass('spinner--fading')).to.equal(true);
  });
  it('should set the width and height to the given size prop', () => {
    const spinner = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_spinner.default, {
      size: 10
    }));
    (0, _chai.expect)(spinner.find('svg').instance().getAttribute('width')).to.be.equal('10');
    (0, _chai.expect)(spinner.find('svg').instance().getAttribute('height')).to.be.equal('10');
  });
  it('should apply classnames given via props', () => {
    const spinner = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_spinner.default, {
      className: "testing-classnames"
    }));
    (0, _chai.expect)(spinner.find(_icon.default).hasClass('testing-classnames')).to.equal(true);
    (0, _chai.expect)(spinner.find(_icon.default).hasClass('spinner--robot')).to.equal(true);
  });
  it('sohuld add a one second delay via props', () => {
    const spinner = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_spinner.default, {
      delay: 1000,
      className: "'testing-classnames"
    }));
    (0, _chai.expect)(spinner.find(_icon.default)).to.not.exist();
    clock.tick(2000);
    spinner.update();
    (0, _chai.expect)(spinner.find(_icon.default)).to.exist();
  });
});