"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactTransitionGroup = require("react-transition-group");

var _reactBeautifulDnd = require("react-beautiful-dnd");

var _fp = require("lodash/fp");

var _tab = _interopRequireDefault(require("./tab"));

var _newTab = _interopRequireDefault(require("./newTab"));

var _overflowIndicator = _interopRequireDefault(require("./overflowIndicator"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const OVERFLOW_THRESHOLD = 20;
const SCROLL_STEP = 180;
const SCROLL_STEP_FRAME = 10;

const transformDragTransform = props => ({
  transform: (0, _fp.replace)(/, -?[\w].*px/, ', 0', props.style.transform)
});

class Tabs extends _react.default.Component {
  constructor() {
    var _this;

    super(...arguments);
    _this = this;

    _defineProperty(this, "state", {
      overflowingLeft: false,
      overflowingRight: false,
      scrollTarget: null
    });

    _defineProperty(this, "onLeftOverflowIndicatorClick", () => {
      this.setState({
        scrollTarget: this.containerRef.scrollLeft - SCROLL_STEP
      }, () => {
        requestAnimationFrame(this.scrollAnimationFrame);
      });
    });

    _defineProperty(this, "onRightOverflowIndicatorClick", () => {
      this.setState({
        scrollTarget: this.containerRef.scrollLeft + SCROLL_STEP
      }, () => {
        requestAnimationFrame(this.scrollAnimationFrame);
      });
    });

    _defineProperty(this, "onDragEnd", result => {
      // dropped outside the list
      if (!result.destination) {
        return;
      }

      this.props.onReorder(result.source.index, result.destination.index);
    });

    _defineProperty(this, "scrollAnimationFrame", () => {
      const {
        scrollTarget
      } = this.state;
      const {
        scrollLeft: currentPosition
      } = this.containerRef;

      if (scrollTarget) {
        if (Math.abs(scrollTarget - currentPosition) < SCROLL_STEP_FRAME) {
          this.containerRef.scrollLeft = scrollTarget;
          this.setState({
            scrollTarget: null
          });
        } else if (scrollTarget > currentPosition) {
          this.containerRef.scrollLeft += SCROLL_STEP_FRAME;
        } else {
          this.containerRef.scrollLeft -= SCROLL_STEP_FRAME;
        }

        requestAnimationFrame(this.scrollAnimationFrame);
      }
    });

    _defineProperty(this, "containerRefCallback", el => {
      this.containerRef = el;
    });

    _defineProperty(this, "checkOverflows", function () {
      let {
        delay
      } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {
        delay: 0
      };
      _this.overflowCheckTimeout = setTimeout(() => {
        if (!_this.containerRef) return;
        const {
          scrollLeft,
          scrollWidth,
          clientWidth
        } = _this.containerRef;
        const overflowingLeft = scrollLeft > OVERFLOW_THRESHOLD;
        const overflowingRight = scrollLeft + clientWidth + OVERFLOW_THRESHOLD < scrollWidth;

        _this.setState({
          overflowingLeft,
          overflowingRight
        });
      }, delay);
    });
  }

  componentDidMount() {
    this.checkOverflows();
    this.containerRef.addEventListener('scroll', this.checkOverflows);
    window.addEventListener('resize', this.checkOverflows);
  }

  componentDidUpdate(prevProps) {
    if (this.props.tabs.length === prevProps.tabs.length + 1) {
      this.containerRef.scrollLeft = this.containerRef.scrollWidth;
    }

    if (prevProps.tabs.length !== this.props.tabs.length) {
      this.checkOverflows({
        delay: 250
      });
    }
  }

  componentWillUnmount() {
    clearTimeout(this.overflowCheckTimeout);
    this.containerRef.removeEventListener('scroll', this.checkOverflows);
    window.removeEventListener('resize', this.checkOverflows);
  }

  render() {
    const {
      overflowingLeft,
      overflowingRight
    } = this.state;
    const {
      tabs,
      activeTab,
      onTabClick,
      onTabClose,
      onNewTabClick,
      canCloseLastTab
    } = this.props;
    return /*#__PURE__*/_react.default.createElement("div", {
      className: "klara-ui-tabs"
    }, /*#__PURE__*/_react.default.createElement(_overflowIndicator.default, {
      direction: "left",
      visible: overflowingLeft,
      onClick: this.onLeftOverflowIndicatorClick
    }), /*#__PURE__*/_react.default.createElement(_overflowIndicator.default, {
      direction: "right",
      visible: overflowingRight,
      onClick: this.onRightOverflowIndicatorClick
    }), /*#__PURE__*/_react.default.createElement("div", {
      className: "klara-ui-tabs__inner",
      ref: this.containerRefCallback
    }, /*#__PURE__*/_react.default.createElement(_reactBeautifulDnd.DragDropContext, {
      onDragEnd: this.onDragEnd
    }, /*#__PURE__*/_react.default.createElement(_reactBeautifulDnd.Droppable, {
      droppableId: "droppable",
      direction: "horizontal"
    }, drop => /*#__PURE__*/_react.default.createElement("div", _extends({
      ref: drop.innerRef
    }, drop.droppableProps), /*#__PURE__*/_react.default.createElement(_reactTransitionGroup.TransitionGroup, {
      className: "klara-ui-tabs__transition-group"
    }, tabs.map((tab, index) => /*#__PURE__*/_react.default.createElement(_reactTransitionGroup.CSSTransition, {
      key: tab.id,
      timeout: 150,
      classNames: "klara-ui-tabs__tab"
    }, /*#__PURE__*/_react.default.createElement(_reactBeautifulDnd.Draggable, {
      draggableId: tab.id,
      index: index
    }, (drag, snapshot) => /*#__PURE__*/_react.default.createElement("div", _extends({
      ref: drag.innerRef
    }, drag.draggableProps, drag.dragHandleProps, {
      style: _objectSpread(_objectSpread({}, drag.draggableProps.style), snapshot.isDragging ? transformDragTransform(drag.draggableProps) : {})
    }), /*#__PURE__*/_react.default.createElement(_tab.default, {
      tab: tab,
      immortal: typeof canCloseLastTab === 'boolean' ? !canCloseLastTab : canCloseLastTab(tabs),
      active: tab.id === activeTab,
      onClick: onTabClick,
      onClose: onTabClose
    }))))), /*#__PURE__*/_react.default.createElement(_newTab.default, {
      onClick: onNewTabClick
    })))))));
  }

}

Tabs.NewTab = _newTab.default;
Tabs.Tab = _tab.default;
Tabs.propTypes = {
  activeTab: _propTypes.default.string,
  tabs: _propTypes.default.arrayOf(_propTypes.default.shape({
    id: _propTypes.default.string.isRequired,
    title: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.object])
  })),
  onTabClose: _propTypes.default.func,
  onTabClick: _propTypes.default.func,
  onNewTabClick: _propTypes.default.func,
  onReorder: _propTypes.default.func,
  canCloseLastTab: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.bool])
};
Tabs.defaultProps = {
  activeTab: null,
  tabs: [],
  onTabClose: () => {},
  onTabClick: () => {},
  onNewTabClick: undefined,
  onReorder: () => {},
  canCloseLastTab: tabs => tabs.length === 1
};
Tabs.propsDescriptions = {};
var _default = Tabs;
exports.default = _default;