"use strict";

var _react = _interopRequireDefault(require("react"));

var _chai = require("chai");

var _enzyme = require("enzyme");

var _sinon = _interopRequireDefault(require("sinon"));

var _tabs = _interopRequireDefault(require("../tabs"));

var _icon = _interopRequireDefault(require("../../icon/icon"));

var _overflowIndicator = _interopRequireDefault(require("../overflowIndicator"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const propEquals = (prop, value) => element => element.props()[prop] === value;

const someTabs = [{
  id: 'aa-11',
  title: 'Lorem Ipsum'
}, {
  id: 'bb-22',
  title: 'Ipsum Ipsum'
}, {
  id: 'cc-33',
  title: 'Dolor Sit Amet'
}, {
  id: 'dd-44',
  title: 'Dolor Lorem Amet'
}];
describe('Tabs', () => {
  it('should render the tabs list with a "div" tag', () => {
    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_tabs.default, {
      tabs: someTabs
    }));
    (0, _chai.expect)(wrapper.find('div')).to.exist();
  });
  it('should call the click handler with the correct tab object when a tab is clicked', () => {
    const onClickSpy = _sinon.default.spy();

    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_tabs.default, {
      onTabClick: onClickSpy,
      tabs: someTabs
    }));
    wrapper.find(_tabs.default.Tab).filterWhere(tab => tab.text() === 'Lorem Ipsum').find('.klara-ui-tabs__tab').simulate('click');
    (0, _chai.expect)(onClickSpy).to.have.been.calledWith(someTabs[0]);
  });
  it('should call the close handler on closing any tab', () => {
    const onCloseStub = _sinon.default.stub();

    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_tabs.default, {
      onTabClose: onCloseStub,
      tabs: someTabs
    }));
    wrapper.find(_tabs.default.Tab).filterWhere(tab => tab.text() === 'Ipsum Ipsum').find(_icon.default).simulate('click');
    (0, _chai.expect)(onCloseStub).to.have.been.called();
  });
  it('should call the new tab handler on clicking that button', () => {
    const onNewTabStub = _sinon.default.stub();

    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_tabs.default, {
      tabs: someTabs,
      onNewTabClick: onNewTabStub
    }));
    wrapper.find(_tabs.default.NewTab).find('button').simulate('click');
    (0, _chai.expect)(onNewTabStub).to.have.been.called();
  });
  describe('Overflowing', () => {
    it("should render an overflow indicator if state 'overflowingRight' is true", () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_tabs.default, {
        tabs: someTabs
      }));
      wrapper.setState({
        overflowingRight: true
      });
      const indicator = wrapper.find(_overflowIndicator.default).filterWhere(propEquals('direction', 'right'));
      (0, _chai.expect)(indicator).to.exist();
      (0, _chai.expect)(indicator.props().visible).to.be.true();
    });
  });
});