"use strict";

var _react = _interopRequireDefault(require("react"));

var _chai = require("chai");

var _enzyme = require("enzyme");

var _sinon = _interopRequireDefault(require("sinon"));

var _textField = _interopRequireDefault(require("../textField"));

var _spinner = _interopRequireDefault(require("../../spinner/spinner"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

describe('TextField', () => {
  describe('Built-in input', () => {
    it('should mount', () => {
      const fieldWrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        label: "Testing Ipsum",
        value: ""
      }));
      (0, _chai.expect)(fieldWrapper).to.exist();
      const multiLineFieldWrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        label: "Testing Ipsum",
        value: "",
        multiLine: true
      }));
      (0, _chai.expect)(multiLineFieldWrapper).to.exist();
    });
    it('should use plain input', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        label: "Testing Ipsum",
        value: ""
      }));
      (0, _chai.expect)(wrapper.find('input')).to.exist();
    });
    it('should use textarea if <multiLine> prop is set', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        multiLine: true,
        label: "Testing Ipsum",
        value: ""
      }));
      (0, _chai.expect)(wrapper.find('textarea')).to.exist();
    });
    it('should reflect <value>', () => {
      let wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: "Some default value"
      }));
      (0, _chai.expect)(wrapper.find('input').prop('value')).to.be.equal('Some default value');
      wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        multiLine: true,
        value: "Some default value"
      }));
      (0, _chai.expect)(wrapper.find('textarea').prop('value')).to.be.equal('Some default value');
    });
    it('should call the given <onChange> on any change', () => {
      const onChangeStub = _sinon.default.stub();

      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: "Anton",
        onChange: onChangeStub
      }));
      wrapper.find('input').props().onChange({
        target: {
          value: 'Lorem Ipsum'
        }
      });
      (0, _chai.expect)(onChangeStub).to.have.been.calledOnce();
      const multiLineWrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        multiLine: true,
        value: "Anton",
        onChange: onChangeStub
      }));
      multiLineWrapper.find('textarea').props().onChange({
        target: {
          value: 'Lorem Ipsum'
        }
      });
      (0, _chai.expect)(onChangeStub).to.have.been.calledTwice();
    });
    it('should not render <label>, <palcaeholder>, <helperText> & <errorText> if not set', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: ""
      }));
      const label = wrapper.find('.text-field__label');
      const placeholder = wrapper.find('.text-field__hint');
      const errorText = wrapper.find('.text-field__error-text');
      const helperText = wrapper.find('.text-field__helper-text');
      (0, _chai.expect)(label.exists()).to.be.false();
      (0, _chai.expect)(placeholder.exists()).to.be.false();
      (0, _chai.expect)(errorText.exists()).to.be.false();
      (0, _chai.expect)(helperText.exists()).to.be.false();
    });
    it('should render <label> with proper value', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: "",
        label: "Proper Label"
      }));
      const label = wrapper.find('.text-field__label');
      (0, _chai.expect)(label.text()).to.be.equal('Proper Label');
    });
    it('should render <placeholder> with proper value', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: "",
        placeholder: "Proper Hint"
      }));
      const input = wrapper.find('input');
      (0, _chai.expect)(input).to.have.attr('placeholder', 'Proper Hint');
    });
    it('should not render <placeholder> if <value> is set', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: "123",
        placeholder: "Proper Hint"
      }));
      const input = wrapper.find('input');
      (0, _chai.expect)(input).to.have.attr('placeholder', '');
    });
    it('should not render <placeholder> if <label> is set when idle', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: "",
        label: "123",
        placeholder: "Proper Hint"
      }));
      const input = wrapper.find('input');
      (0, _chai.expect)(input).to.have.attr('placeholder', '');
    });
    it('should render <helperText> with proper value', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: "",
        helperText: "Helper text"
      }));
      const helperText = wrapper.find('.text-field__helper-text');
      (0, _chai.expect)(helperText.text()).to.be.eql('Helper text');
    });
    it('should render <helperText> using a render prop if supplied', () => {
      const renderHelper = () => /*#__PURE__*/_react.default.createElement("span", null, "Kanske ett datum h\xE4r");

      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: "",
        helperText: "",
        renderHelperText: renderHelper
      }));
      const helperText = wrapper.find('.text-field__helper-text');
      (0, _chai.expect)(helperText.text()).to.be.eql('Kanske ett datum här');
    });
    it('should render <errorText> with proper value & trigger error-state', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: "",
        errorText: "Error Description"
      }));
      const errorText = wrapper.find('.text-field__error-text'); // .hasClass() on wrapper is tricky with mount()...

      (0, _chai.expect)(wrapper.children().hasClass('text-field--invalid')).to.be.true();
      (0, _chai.expect)(errorText.exists()).to.be.true();
      (0, _chai.expect)(errorText.text()).to.be.eql('Error Description');
    });
    it('should prefer <errorText> over <helperText> if both are set', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: "",
        helperText: "Text",
        errorText: "Error Description"
      }));
      const errorText = wrapper.find('.text-field__error-text');
      const helperText = wrapper.find('.text-field__helper-text');
      (0, _chai.expect)(errorText.exists()).to.be.true();
      (0, _chai.expect)(helperText.exists()).to.be.false();
    });
    it('should render loader if <loading> property is set', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        label: "With Icon",
        value: "",
        loading: true
      }));
      const spinner = wrapper.find(_spinner.default);
      (0, _chai.expect)(spinner).to.exist();
      (0, _chai.expect)(spinner.props().type).to.equal('fading');
    });
    it('should not render counter by default and if <maxLength> is less then zero', () => {
      let wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: ""
      }));
      (0, _chai.expect)(wrapper.find('.field-counter').exists()).to.be.false();
      wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        maxLength: -100,
        value: ""
      }));
      (0, _chai.expect)(wrapper.find('.field-counter').exists()).to.be.false();
    });
    it('should show counter if <maxLength> is greater then zero', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        maxLength: 10,
        value: ""
      }));
      (0, _chai.expect)(wrapper.find('.field-counter').exists()).to.be.true();
      (0, _chai.expect)(wrapper.find('.field-counter').hasClass('text-field__counter')).to.be.true();
    });
    it('should not count urls if we specify a <counterFunc>', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        maxLength: 30,
        value: "R\xE4kna https://placebear.com/464/261 bara dessa 28 tecken https://www.google.se/",
        counterFunc: (max, value) => max - value.replace(/(?:https?):\/\/[\n\S]+/g, '').length
      }));
      const characterCount = parseInt(wrapper.find('.field-counter').text(), 10);
      (0, _chai.expect)(characterCount).to.equal(2);
    });
    it('should reflect difference between <maxLength> and <value> length in counter', () => {
      let wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        maxLength: 10,
        value: ""
      }));
      (0, _chai.expect)(wrapper.find('.field-counter').text()).to.have.string('10');
      wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        maxLength: 10,
        value: "ab"
      }));
      (0, _chai.expect)(wrapper.find('.field-counter').text()).to.have.string('8');
      wrapper.setProps({
        value: 'abcd'
      });
      (0, _chai.expect)(wrapper.find('.field-counter').text()).to.have.string('6');
    });
    it('should render "maxed" counter if <value> length is greater then <maxLength>', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        maxLength: 2,
        value: "True"
      }));
      (0, _chai.expect)(wrapper.find('.field-counter').text()).to.have.string('-2');
      (0, _chai.expect)(wrapper.find('.field-counter').hasClass('field-counter--maxed')).to.be.true();
    });
    it('should set <maxLength> for input control if <maxLength> and <shouldClipAtMaxLength> are set', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: "",
        maxLength: 10,
        shouldClipAtMaxLength: true
      }));
      (0, _chai.expect)(wrapper.find('input').prop('maxLength')).to.be.equal(10);
    });
    it('should not set <maxLength> for input control if <shouldClipAtMaxLength> is set, but <maxLength> is not', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: "",
        shouldClipAtMaxLength: true
      }));
      (0, _chai.expect)(wrapper.find('input').prop('maxLength')).to.be.equal(-1);
    });
    it('should go into disabled-state if <disabled> property is set', () => {
      let wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: "Anton",
        disabled: true
      }));
      let input = wrapper.find('input');
      (0, _chai.expect)(wrapper.children().hasClass('text-field--disabled')).to.be.true();
      (0, _chai.expect)(input.prop('disabled')).to.be.true();
      wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        multiLine: true,
        value: "Anton",
        disabled: true
      }));
      input = wrapper.find('textarea');
      (0, _chai.expect)(wrapper.children().hasClass('text-field--disabled')).to.be.true();
      (0, _chai.expect)(input.prop('disabled')).to.be.true();
    });
    it('should go into filled-state if <value> property is set', () => {
      let wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: ""
      }));
      (0, _chai.expect)(wrapper.children().hasClass('text-field--filled')).to.be.false();
      wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: 123
      }));
      (0, _chai.expect)(wrapper.children().hasClass('text-field--filled')).to.be.true();
    });
    it('should go focus input control if click on wrapper', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: ""
      }));
      const input = wrapper.find('input').getDOMNode();

      const focusStub = _sinon.default.stub(input, 'focus'); // I would rather trigger focus on wrapper
      // but this won't work, since internally use node.focus();


      wrapper.children().simulate('focus');
      (0, _chai.expect)(focusStub).to.be.calledOnce();
    });
    it('should go into focused-state if click on input control', () => {
      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: ""
      })); // I would rather trigger focus on wrapper
      // but this won't work, since internally use node.focus();

      wrapper.find('input').simulate('focus');
      (0, _chai.expect)(wrapper.children().hasClass('text-field--focused')).to.be.true();
      (0, _chai.expect)(wrapper.state()).to.have.property('focused', true);
    });
    it('should call the given <onBlur> on internal input blur event', () => {
      const onBlurStub = _sinon.default.stub();

      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: "Anton",
        onBlur: onBlurStub
      }));
      wrapper.find('input').simulate('blur');
      (0, _chai.expect)(onBlurStub).to.have.been.calledOnce();
    });
    it('should call the given <onFocus> on internal input focus event', () => {
      const onFocusStub = _sinon.default.stub();

      const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
        value: "Anton",
        onFocus: onFocusStub
      }));
      wrapper.find('input').simulate('focus');
      (0, _chai.expect)(onFocusStub).to.have.been.calledOnce();
    });
  });
  it('should use the renderProp if supplied', () => {
    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
      value: "",
      renderInput: inputProps => /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement("span", null, "Special stuff"), /*#__PURE__*/_react.default.createElement("input", _extends({
        type: "text"
      }, inputProps)), ' ')
    }));
    wrapper.setProps({
      value: 'Lorem Ipsum'
    });
    (0, _chai.expect)(wrapper.find('span').text()).to.equal('Special stuff');
  });
  it('should be password type', () => {
    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
      value: "123",
      type: "password"
    }));
    const input = wrapper.find('input');
    (0, _chai.expect)(input).to.have.attr('type', 'password');
  });
  it('should be email type', () => {
    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
      value: "123",
      type: "email"
    }));
    const input = wrapper.find('input');
    (0, _chai.expect)(input).to.have.attr('type', 'email');
  });
  it('should be url type', () => {
    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
      value: "123",
      type: "url"
    }));
    const input = wrapper.find('input');
    (0, _chai.expect)(input).to.have.attr('type', 'url');
  });
  it('should be text type when type is missing', () => {
    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
      value: "123"
    }));
    const input = wrapper.find('input');
    (0, _chai.expect)(input).to.have.attr('type', 'text');
  });
  it('should call the onEnter callback if given', () => {
    const onEnterStub = _sinon.default.stub();

    const input = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_textField.default, {
      value: "kim",
      onEnter: onEnterStub
    }));
    input.find('input').simulate('keyPress', {
      key: 'Enter'
    });
    (0, _chai.expect)(onEnterStub).to.have.been.called();
  });
});