"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _spinner = _interopRequireDefault(require("../spinner/spinner"));

var _fieldCounter = _interopRequireDefault(require("./fieldCounter"));

var _inputText = _interopRequireDefault(require("./inputText"));

var _inputMultiLine = _interopRequireDefault(require("./inputMultiLine"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class TextField extends _react.default.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "onWrapFocus", e => {
      const {
        disabled
      } = this.props;

      if (disabled || e.target !== this.containerRef) {
        return;
      }

      this.focus();
    });

    _defineProperty(this, "onFocus", e => {
      this.props.onFocus(e);
      this.setState({
        focused: true
      });
    });

    _defineProperty(this, "onBlur", e => {
      this.props.onBlur(e);
      this.setState({
        focused: false
      });
    });

    _defineProperty(this, "onChange", value => {
      this.props.onChange(value);
    });

    _defineProperty(this, "onKeyPress", event => {
      const {
        onEnter
      } = this.props;

      if (event.key === 'Enter') {
        onEnter(event);
      }

      this.props.onKeyPress(event);
    });

    _defineProperty(this, "onInput", event => {
      this.props.onInput(event);
    });

    _defineProperty(this, "focus", () => {
      this.inputRef.focus();
    });

    _defineProperty(this, "clear", () => {
      this.inputRef.textContent = '';
      this.inputRef.value = '';
    });

    this.state = {
      focused: false
    };
  }

  getPlaceholder() {
    const {
      label,
      staticLabel,
      placeholder,
      value
    } = this.props;
    const {
      focused
    } = this.state;

    if (value) {
      return '';
    }

    if (label && !focused && !staticLabel) {
      return '';
    }

    return placeholder;
  }

  pickInput(inputProps) {
    const {
      multiLine,
      renderInput
    } = this.props;

    if (renderInput) {
      return renderInput(inputProps);
    }

    const Input = multiLine ? _inputMultiLine.default : _inputText.default;
    return /*#__PURE__*/_react.default.createElement(Input, inputProps);
  }

  renderIcon() {
    const icon = this.props.loading ? /*#__PURE__*/_react.default.createElement(_spinner.default, {
      type: "fading",
      size: 18
    }) : this.props.icon;
    return icon && /*#__PURE__*/_react.default.createElement("span", {
      className: "text-field__icon"
    }, icon);
  }

  render() {
    const {
      focused
    } = this.state;
    const {
      counterFunc,
      className,
      disabled,
      errorText,
      helperText,
      label,
      markRequired,
      maxLength,
      min,
      renderHelperText,
      shouldClipAtMaxLength,
      staticLabel,
      step,
      type,
      value,
      preventFocus
    } = this.props;
    const labelText = label + (markRequired ? ' (obligatoriskt)' : '');
    const nativeMaxLength = shouldClipAtMaxLength && maxLength || -1;
    const filled = staticLabel || `${value}`.length > 0;
    const inputProps = {
      className: 'text-field__control',
      disabled,
      maxLength: nativeMaxLength,
      min,
      onBlur: this.onBlur,
      onChange: this.onChange,
      onFocus: this.onFocus,
      placeholder: this.getPlaceholder(),
      onKeyPress: this.onKeyPress,
      onInput: this.onInput,
      ref: input => {
        this.inputRef = input;
      },
      step,
      type,
      value
    };
    const input = this.pickInput(inputProps);
    const rootClasses = (0, _classnames.default)('text-field', className, {
      'text-field--filled': filled,
      'text-field--has-label': label,
      'text-field--invalid': errorText,
      'text-field--focused': focused && !preventFocus,
      'text-field--disabled': disabled
    });
    return /*#__PURE__*/_react.default.createElement("div", {
      tabIndex: "-1",
      className: rootClasses,
      onFocus: this.onWrapFocus,
      ref: _ref => {
        this.containerRef = _ref;
      }
    }, label && /*#__PURE__*/_react.default.createElement("label", {
      className: "text-field__label"
    }, labelText), /*#__PURE__*/_react.default.createElement("div", {
      className: "text-field__input-container"
    }, input, this.renderIcon()), /*#__PURE__*/_react.default.createElement("div", {
      className: "text-field__floor-wrap"
    }, /*#__PURE__*/_react.default.createElement("hr", {
      className: "text-field__floor"
    })), /*#__PURE__*/_react.default.createElement("div", {
      className: "text-field__footer"
    }, errorText && /*#__PURE__*/_react.default.createElement("div", {
      className: "text-field__error-text"
    }, errorText), !errorText && helperText && !renderHelperText && /*#__PURE__*/_react.default.createElement("div", {
      className: "text-field__helper-text"
    }, helperText), !errorText && renderHelperText && /*#__PURE__*/_react.default.createElement("div", {
      className: "text-field__helper-text"
    }, renderHelperText()), /*#__PURE__*/_react.default.createElement(_fieldCounter.default, {
      className: "text-field__counter",
      maxLength: maxLength,
      value: value,
      counterFunc: counterFunc
    })));
  }

}

TextField.propTypes = {
  className: _propTypes.default.string,
  counterFunc: _propTypes.default.func,
  disabled: _propTypes.default.bool,
  errorText: _propTypes.default.string,
  helperText: _propTypes.default.string,
  label: _propTypes.default.string,
  loading: _propTypes.default.bool,
  icon: _propTypes.default.element,
  markRequired: _propTypes.default.bool,
  maxLength: _propTypes.default.number,
  min: _propTypes.default.number,
  multiLine: _propTypes.default.bool,
  onBlur: _propTypes.default.func,
  onChange: _propTypes.default.func,
  onKeyPress: _propTypes.default.func,
  onInput: _propTypes.default.func,
  onFocus: _propTypes.default.func,
  onEnter: _propTypes.default.func,
  placeholder: _propTypes.default.string,
  renderHelperText: _propTypes.default.func,
  renderInput: _propTypes.default.func,
  shouldClipAtMaxLength: _propTypes.default.bool,
  staticLabel: _propTypes.default.bool,
  step: _propTypes.default.number,
  type: _propTypes.default.string,
  value: _propTypes.default.oneOfType([_propTypes.default.object, _propTypes.default.string, _propTypes.default.number]).isRequired,
  preventFocus: _propTypes.default.bool
};
TextField.defaultProps = {
  className: '',
  counterFunc: (max, value) => max - value.length,
  disabled: false,
  errorText: '',
  helperText: '',
  label: '',
  loading: false,
  icon: null,
  markRequired: false,
  maxLength: -1,
  min: null,
  multiLine: false,
  onBlur: () => {},
  onChange: () => {},
  onKeyPress: () => {},
  onInput: () => {},
  onFocus: () => {},
  onEnter: () => {},
  placeholder: '',
  renderHelperText: null,
  renderInput: null,
  shouldClipAtMaxLength: false,
  staticLabel: false,
  step: 1,
  type: 'text',
  preventFocus: false
};
TextField.propDescriptions = {
  className: 'Any combination of CSS classnames',
  counterFunc: 'Function that returns the value shown in FieldCounter. Default: (max, value) => max - value.length',
  disabled: 'Controls whether user can interact with control or not',
  errorText: "If set triggers error-state for control, also shown under entered text describing what's happened",
  helperText: 'One more descriptive string, displayed under entered text',
  label: 'A descriptive label.',
  loading: 'Controls whether or not to display loading spinner',
  icon: 'Optionally supply an icon that will display to the right of the text',
  markRequired: "Show '*' sign after label name. You still have to implement validation yourself ;)",
  maxLength: 'If set will show backward counter for current text length',
  multiLine: 'If set will use expandable textarea instead of plain input',
  onBlur: 'Callback which runs with internal input blur event',
  onChange: 'Callback which runs as the field changes value',
  onKeyPress: 'Callback which runs on keypress',
  onFocus: 'Callback which runs with internal input focus event',
  onEnter: 'Callback which runs when enter is pressed in the input',
  placeholder: "Additional descriptive string, will be displayed on label's place when field is active",
  shouldClipAtMaxLength: "If set will disallow text after max lenght limit is reached. However it won't clip value coming from props",
  value: 'String value displayed in the field',
  renderInput: 'custom renderProp for the input field'
};
var _default = TextField;
exports.default = _default;