"use strict";

var _react = _interopRequireDefault(require("react"));

var _chai = require("chai");

var _enzyme = require("enzyme");

var _textHighlight = _interopRequireDefault(require("../textHighlight"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('TextHighlight', () => {
  it('should not alter text content', () => {
    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_textHighlight.default, {
      highlight: "bar"
    }, "foobar and more bare")));
    (0, _chai.expect)(wrapper.text()).to.equal('foobar and more bare');
  });
  it('should not highlight anything for empty input', () => {
    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_textHighlight.default, {
      highlight: ""
    }, "foobar with bar and more")));
    (0, _chai.expect)(wrapper.find('.text-highlight__fragment')).to.not.exist();
    (0, _chai.expect)(wrapper.text()).to.equal('foobar with bar and more');
  });
  it('should highlight all matches', () => {
    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_textHighlight.default, {
      highlight: "bar"
    }, "foobar with bar and more")));
    const textFragments = wrapper.find('mark').map(n => n.text());
    (0, _chai.expect)(textFragments).to.have.length(2);
    (0, _chai.expect)(textFragments).to.deep.equal(['bar', 'bar']);
  });
  it('should highlight case insensitive', () => {
    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_textHighlight.default, {
      highlight: "bar"
    }, "foobar with Bar")));
    const textFragments = wrapper.find('mark').map(n => n.text());
    (0, _chai.expect)(textFragments).to.have.length(2);
    (0, _chai.expect)(textFragments).to.deep.equal(['bar', 'Bar']);
  });
  it('should use render prop if provided', () => {
    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_textHighlight.default, {
      highlight: "bar",
      renderHighlight: (fragment, highlightProps) => /*#__PURE__*/_react.default.createElement("article", highlightProps, fragment)
    }, "foobar with Bar")));
    const textFragments = wrapper.find('article').map(n => n.text());
    (0, _chai.expect)(textFragments).to.have.length(2);
    (0, _chai.expect)(textFragments).to.deep.equal(['bar', 'Bar']);
  });
  it('should hand regex like string', () => {
    const wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_textHighlight.default, {
      highlight: ".*"
    }, "string.*")));
    const textFragments = wrapper.find('mark').map(n => n.text());
    (0, _chai.expect)(textFragments).to.have.length(1);
    (0, _chai.expect)(textFragments).to.deep.equal(['.*']);
    (0, _chai.expect)(wrapper.text()).to.deep.equal('string.*');
  });
});