import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';

import Icon from '../icon/icon';

class Accordion extends React.Component {
  state = {
    height: 'auto',
    canExpand: false,
    isExpanded: false,
  };

  componentDidMount() {
    requestAnimationFrame(() => {
      const { clipHeight } = this.props;
      if (clipHeight) {
        if (this.snapshotHeight() > clipHeight) {
          this.setState({ canExpand: true, height: clipHeight });
        }
      }
    });
  }

  accordionRef = React.createRef();

  buttonTexts = [this.props.textOpen, this.props.textClose];

  snapshotHeight = () =>
    this.accordionRef.current
      ? Math.round(this.accordionRef.current.getBoundingClientRect().height)
      : null;

  toggleOpen = () => {
    const { clipHeight } = this.props;
    if (this.snapshotHeight() === clipHeight) {
      this.setState({ isExpanded: true });
      this.accordionRef.current.style.height = 'auto';
      requestAnimationFrame(() => {
        const snapshotHeight = this.snapshotHeight();
        this.accordionRef.current.style.height = `${clipHeight}px`;
        requestAnimationFrame(() => {
          this.setState({ height: snapshotHeight });
        });
      });
    } else {
      this.setState({ isExpanded: false });
      requestAnimationFrame(() => {
        this.accordionRef.current.style.height = `${this.snapshotHeight()}px`;
        requestAnimationFrame(() => {
          this.setState({ height: clipHeight });
        });
      });
    }
  };

  render() {
    const { children, clipHeight, handleColor } = this.props;
    const { height, canExpand, isExpanded } = this.state;
    const block = 'klara-ui-accordion';
    const classes = classNames(block, {
      [`${block}--can-expand`]: canExpand,
    });
    const style = {
      background: `linear-gradient(to bottom, transparent, ${handleColor} 30%)`,
    };

    if (height !== 'auto' && height !== clipHeight) {
      const transitionend = () => {
        this.setState({ height: 'auto' });
        this.accordionRef.current.removeEventListener(
          'transitionend',
          transitionend
        );
      };

      this.accordionRef.current.addEventListener(
        'transitionend',
        transitionend
      );
    }

    const buttonText = this.buttonTexts[Number(isExpanded)];

    return (
      <div
        className={classes}
        ref={this.accordionRef}
        style={canExpand ? { height } : {}}
      >
        {children}
        {canExpand && (
          <button
            className={`${block}__handle`}
            onClick={this.toggleOpen}
            style={style}
          >
            <React.Fragment>
              <Icon shape={isExpanded ? 'chevron_up' : 'chevron_down'} />
              {buttonText && <span>{buttonText}</span>}
            </React.Fragment>
          </button>
        )}
      </div>
    );
  }
}

Accordion.propTypes = {
  children: PropTypes.node,
  clipHeight: PropTypes.oneOfType([PropTypes.number, PropTypes.bool]),
  textOpen: PropTypes.string,
  textClose: PropTypes.string,
  handleColor: PropTypes.string,
};

Accordion.defaultProps = {
  children: null,
  clipHeight: false,
  textOpen: '',
  textClose: '',
  handleColor: '#ffffff',
};

Accordion.propDescriptions = {
  children: '',
  clipHeight: 'A number of pixels (example 100)',
  textOpen: 'Text to sit next to the arrow icon when closed',
  textClose: 'Text to sit next to the arrow icon when opened',
  handleColor: 'Background color for the handle',
};

export default Accordion;
