import PropTypes from 'prop-types';
import React from 'react';
import classnames from 'classnames';

import Icon from '../icon/icon';

const Badge = ({
  icon,
  children,
  className,
  onIconClick,
  rightAlignedIcon,
  type,
  tabIndex,
  innerRef,
}) => {
  const classes = classnames(
    'badge',
    {
      'badge--right-aligned-icon': rightAlignedIcon,
      [`badge--${type}`]: type,
    },
    className
  );
  return (
    <div className={classes} ref={innerRef} tabIndex={tabIndex}>
      {icon && (
        <Icon
          className="badge__container__icon"
          shape={icon}
          onClick={onIconClick}
          small
        />
      )}
      {children}
    </div>
  );
};

Badge.propTypes = {
  className: PropTypes.string,
  onIconClick: PropTypes.func,
  icon: PropTypes.string,
  children: PropTypes.node.isRequired,
  rightAlignedIcon: PropTypes.bool,
  type: PropTypes.string,
  innerRef: PropTypes.func,
  tabIndex: PropTypes.number,
};

Badge.defaultProps = {
  className: '',
  icon: null,
  onIconClick: () => {},
  rightAlignedIcon: false,
  tabIndex: undefined,
  innerRef: undefined,
  type: '',
};

Badge.propDescriptions = {
  type: 'One of dark, darker, success',
};

export default Badge;
