import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';

class Crow extends React.Component {
  customStyle = index => {
    if (this.props.wingSpan === 'auto') return {};

    return {
      flex: this.props.wingSpan[index],
    };
  };

  render() {
    const {
      wingSpan,
      className,
      up,
      right,
      down,
      left,
      style,
      gutter,
    } = this.props;

    const block = 'crow';

    const classes = classNames(className, block, {
      [`${block}__ws-auto`]: wingSpan === 'auto',
      [`${block}__up`]: up,
      [`${block}__right`]: right,
      [`${block}__down`]: down,
      [`${block}__left`]: left,
      [`${block}__gutter-${gutter}`]: gutter,
    });
    return (
      <div className={classes} style={style}>
        {React.Children.map(this.props.children, (child, index) =>
          React.cloneElement(child, {
            ...child.props,
            style: { ...child.props.style, ...this.customStyle(index) },
          })
        )}
      </div>
    );
  }
}

Crow.propTypes = {
  wingSpan: PropTypes.oneOfType([
    PropTypes.arrayOf(PropTypes.number),
    PropTypes.string,
  ]),
  gutter: PropTypes.oneOf(['', 'small', 'medium', 'large']),
  style: PropTypes.object, // eslint-disable-line react/forbid-prop-types
  up: PropTypes.bool,
  right: PropTypes.bool,
  down: PropTypes.bool,
  left: PropTypes.bool,
  className: PropTypes.string,
  children: PropTypes.node,
};

Crow.defaultProps = {
  wingSpan: '',
  gutter: '',
  style: {},
  up: false,
  right: false,
  down: false,
  left: false,
  className: '',
  children: null,
};

Crow.propDescriptions = {
  wingSpan:
    '"auto" or an array with ints, corresponding to the wanted child width. Uses flexbox relative values.',
  gutter: 'small, medium or large',
  style: 'Custom styles',
  up: 'Position top',
  right: 'Position right',
  down: 'Position down',
  left: 'Position left',
  className: 'Custom className',
  children: 'HTML-element or <Component />',
};

export default Crow;
