import React, { Component } from 'react';
import PropTypes from 'prop-types';
import moment from 'moment';
import classnames from 'classnames';

class Timepicker extends Component {
  onInputChange = e => {
    const { onChange, date } = this.props;
    const [hour, minute] = e.target.value.split(':');

    onChange(
      moment(date || moment())
        .hour(hour)
        .minute(minute)
        .seconds(0)
    );
  };

  render() {
    const { date, disabled } = this.props;
    const value = moment.isMoment(date) ? date.format('HH:mm') : '--:--';
    const className = classnames('kui-timepicker', {
      'kui-timepicker--disabled': disabled,
    });

    return (
      <div className={className}>
        <label>Tid:</label>
        <input
          disabled={disabled}
          type="time"
          value={value}
          onChange={this.onInputChange}
        />
      </div>
    );
  }
}

Timepicker.propTypes = {
  date: PropTypes.shape({
    hour: PropTypes.func.isRequired,
    minute: PropTypes.func.isRequired,
    format: PropTypes.func.isRequired,
  }),
  onChange: PropTypes.func.isRequired,
  disabled: PropTypes.bool,
};

Timepicker.defaultProps = {
  date: null,
  disabled: false,
};

export default Timepicker;
