import React from 'react';
import PropTypes from 'prop-types';
import Popover from '../popover/popover';

export default class AnchoredMenu extends React.Component {
  state = {
    open: false,
  };

  componentWillUnmount() {
    const root = this.ref.current.getRootNode();
    root.removeEventListener('click', this.handleAllClicks);
  }

  ref = React.createRef();

  anchorRef = React.createRef();

  toggleIsOpen = () => (this.state.open ? this.close() : this.open());

  open = () => {
    this.setState({ open: true });
    const root = this.ref.current.getRootNode();
    root.addEventListener('click', this.handleAllClicks);
    this.props.onOpen();
  };

  close = () => {
    this.setState({ open: false });
    const root = this.ref.current.getRootNode();
    root.removeEventListener('click', this.handleAllClicks);
    this.props.onClose();
  };

  focus = () => {
    if (this.anchorRef.current && this.anchorRef.current.focus) {
      this.anchorRef.current.focus();
    }
  };

  handleAllClicks = ({ target }) => {
    const node = this.ref.current;
    return node.contains(target) || this.close();
  };

  handleKeyDown = event => {
    switch (event.key) {
      case 'Escape':
        return this.close();
      case 'ArrowDown':
      case 'ArrowUp':
        event.preventDefault();
        return this.state.open ? this.props.onArrowKey(event.key) : this.open();
      case 'Tab':
        return this.state.open && event.preventDefault();
      case 'Enter':
      case ' ':
        return (
          this.state.open &&
          this.props.onEnter(event, {
            closeMenu: this.close,
            focusAnchor: this.focus,
          })
        );
      default:
        return null;
    }
  };

  render() {
    const {
      popoverProps,
      renderMenu,
      renderAnchor,
      onEnter,
      onArrowKey,
      onOpen,
      ...wrapperProps
    } = this.props;
    return (
      <div {...wrapperProps} ref={this.ref} onKeyDown={this.handleKeyDown}>
        {this.props.renderAnchor(
          this.toggleIsOpen,
          this.anchorRef,
          this.state.open
        )}
        {this.state.open && (
          <Popover
            {...this.props.popoverProps}
            anchorNode={this.anchorRef.current}
          >
            {this.props.renderMenu({
              closeMenu: this.close,
              focusAnchor: this.focus,
            })}
          </Popover>
        )}
      </div>
    );
  }
}

AnchoredMenu.defaultProps = {
  popoverProps: {},
  onArrowKey: () => {},
  onEnter: () => {},
  onOpen: () => {},
  onClose: () => {},
};

AnchoredMenu.propTypes = {
  renderAnchor: PropTypes.func.isRequired,
  onOpen: PropTypes.func,
  onClose: PropTypes.func,
  onArrowKey: PropTypes.func,
  onEnter: PropTypes.func,
  popoverProps: PropTypes.shape(),
  renderMenu: PropTypes.func.isRequired,
};
