import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';

import Icon from './../icon/icon';

const block = 'drop-down-option';

const DropDownOption = ({
  value,
  label,
  isSelected,
  isHighlighted,
  onMouseEnter,
  onSelect,
}) => {
  const className = classNames(
    block,
    { [`${block}--selected`]: isSelected },
    { [`${block}--highlighted`]: isHighlighted }
  );
  return (
    <div
      onMouseEnter={() => onMouseEnter(value)}
      className={className}
      onClick={() => onSelect(value)}
    >
      {isSelected && <Icon shape="check" small />}
      <span>{label}</span>
    </div>
  );
};

DropDownOption.propTypes = {
  value: PropTypes.oneOfType([
    PropTypes.number,
    PropTypes.bool,
    PropTypes.string,
  ]).isRequired,
  label: PropTypes.string.isRequired,
  isSelected: PropTypes.bool.isRequired,
  isHighlighted: PropTypes.bool.isRequired,
  onSelect: PropTypes.func.isRequired,
  onMouseEnter: PropTypes.func.isRequired,
};

export default DropDownOption;
