import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import Button from '../button/button';
import Dropdown from './dropdown';
import Icon from '../icon/icon';

export default class IconDropdown extends React.Component {
  render() {
    const { options, selectedValue, onChange, popoverProps } = this.props;
    const selectedOption = options.find(({ value }) => value === selectedValue);
    return (
      <Dropdown
        renderButton={(onClick, ref) => (
          <Button
            type="ghost"
            ref={ref}
            icon={selectedOption && selectedOption.icon}
            onClick={onClick}
          />
        )}
        options={options}
        onChange={onChange}
        popoverProps={{
          contentClassName: '',
          withoutArrow: false,
          ...popoverProps,
        }}
        renderOption={(option, highlighted, onClick, onMouseEnter) => (
          <div
            key={option.value}
            onMouseEnter={onMouseEnter}
            onClick={onClick}
            className={classNames('drop-down-option', {
              'drop-down-option--highlighted': highlighted,
            })}
          >
            <Icon shape={option.icon} small />
            {option.label}
          </div>
        )}
      />
    );
  }
}

IconDropdown.propTypes = {
  onChange: PropTypes.func.isRequired,
  popoverProps: PropTypes.shape(),
  options: PropTypes.arrayOf(
    PropTypes.shape({
      value: PropTypes.string.isRequired,
      label: PropTypes.string.isRequired,
    })
  ).isRequired,
  selectedValue: PropTypes.string.isRequired,
};

IconDropdown.defaultProps = {
  popoverProps: {},
};
