import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import customShapes from '../../utils/customShapes';
import standardShapes from '../../utils/standardShapes';

const Icon = ({ className, size, shape, small, type, onClick }) => {
  const iconClasses = classNames(className, 'icon', `icon--${type}`);
  let svgPath;
  let specificSize = size;
  let viewBoxSize = size;
  const sizes = { small: '18', medium: '24', large: '30' };

  if (standardShapes[shape]) {
    const isSmall = small || size === 'small';
    const pathType = isSmall ? 'smallPath' : 'largePath';
    svgPath = standardShapes[shape][pathType] || standardShapes[shape].path;
    viewBoxSize = isSmall ? '18' : '24';

    if (sizes[size]) specificSize = sizes[size];
  } else if (customShapes[shape]) {
    svgPath = customShapes[shape].path;
    viewBoxSize = customShapes[shape].viewPort;
  } else {
    return null;
  }

  return (
    <svg
      className={iconClasses}
      dangerouslySetInnerHTML={{ __html: svgPath }} // eslint-disable-line react/no-danger
      height={specificSize || viewBoxSize}
      onClick={onClick}
      viewBox={`0 0 ${viewBoxSize} ${viewBoxSize}`}
      width={specificSize || viewBoxSize}
    />
  );
};

Icon.propTypes = {
  className: PropTypes.string,
  shape: PropTypes.string.isRequired,
  size: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
  small: PropTypes.bool,
  type: PropTypes.string,
  onClick: PropTypes.func,
};

Icon.defaultProps = {
  className: '',
  size: null,
  small: false,
  type: 'default',
  onClick: () => {},
};

Icon.propDescriptions = {
  className: 'Any combination of CSS class names',
  shape: 'Any of the icons listed above',
  size:
    'Send a string with "small", "medium" or "large" or specify exact size of the icon in number of pixels.',
  small: '(DEPRECATED) Make the size one of the pre-defined ones',
};

export default Icon;
