import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';

const childRenderer = (child, debug) => {
  if (debug) {
    return (
      <li>
        <div className="klara-ui-list__debug-wrapper">{child}</div>
      </li>
    );
  }

  return <li>{child}</li>;
};

const List = props => {
  const {
    autoSize,
    className,
    padding,
    centered,
    direction,
    children,
    debug,
  } = props;

  const block = 'klara-ui-list';
  const classes = classNames(className, block, {
    [`${block}__auto-size`]: autoSize,
    [`${block}__padding-${padding}`]: padding,
    [`${block}__centered`]: centered,
    [`${block}__${direction}`]: direction,
    [`${block}__debug`]: debug,
  });

  return (
    <ul className={classes}>
      {React.Children.map(
        children,
        child => (child ? childRenderer(child, debug) : null)
      )}
    </ul>
  );
};

List.propTypes = {
  autoSize: PropTypes.bool,
  padding: PropTypes.string,
  centered: PropTypes.bool,
  direction: PropTypes.string,
  className: PropTypes.string,
  children: PropTypes.node,
  debug: PropTypes.bool,
};

List.defaultProps = {
  autoSize: false,
  padding: 'none',
  centered: false,
  direction: 'center-center',
  className: '',
  children: null,
  debug: false,
};

List.propDescriptions = {
  autoSize: 'true to make list items stretch evenly',
  padding: 'none, small, medium or large',
  direction: 'right, down, left, up or center-center',
  children: 'HTML-element or <Component />',
  debug: 'Turn on visual debug mode',
};

export default List;
