import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import { compact } from 'lodash/fp';

import List from '../list/list';

class MenuBar extends React.Component {
  state = {
    activeMenuIndex: this.props.initialActiveMenuIndex,
  };

  render() {
    const {
      children,
      className,
      horizontal,
      theme,
      style,
      initialActiveMenuIndex,
    } = this.props;
    const block = 'kui-menu-bar';
    const classes = classNames(block, className, {
      [`${block}__horizontal`]: horizontal,
      [`${block}__${theme}`]: theme,
    });

    return (
      <div className={classes} style={style}>
        <List direction={horizontal ? 'left' : 'up'}>
          {React.Children.map(compact(children), (child, i) => {
            const { props: childProps } = child;
            const { activeMenuIndex } = this.state;

            const classToAppend = classNames(childProps.className, {
              active: i === activeMenuIndex,
            });

            const mergeProps = {
              ...childProps,
              className: classToAppend,
              onClick: () => {
                if (initialActiveMenuIndex !== -1) {
                  this.setState({ activeMenuIndex: i });
                }
                childProps.onClick();
              },
            };

            return React.cloneElement(child, mergeProps);
          })}
        </List>
      </div>
    );
  }
}

MenuBar.propTypes = {
  children: PropTypes.node,
  style: PropTypes.shape(),
  className: PropTypes.string,
  horizontal: PropTypes.bool,
  theme: PropTypes.string,
  initialActiveMenuIndex: PropTypes.number,
};

MenuBar.defaultProps = {
  style: {},
  className: '',
  horizontal: false,
  theme: 'white',
  initialActiveMenuIndex: -1,
  children: null,
};

MenuBar.propDescriptions = {
  children: `Takes klara ui <Button>'s`,
  style: 'Custom styles',
  className: 'Custom classnames',
  horizontal: 'Render as a horizontal menu, defaults to vertical',
  theme: 'The color theme of the menu bar. White or gray.',
  initialActiveMenuIndex:
    'Which menu item should start off as active (array index)',
};

export default MenuBar;
