import React from 'react';
import { expect } from 'chai';
import { mount } from 'enzyme';

import MenuBar from './../menuBar';
import Button from './../../button/button';

describe('MenuBar', () => {
  it('should render a MenuBar', () => {
    const menuBar = mount(
      <MenuBar>
        <Button>First</Button>
        <Button>Second</Button>
      </MenuBar>
    );
    expect(menuBar).to.have.className('kui-menu-bar');
  });

  it('should render a horizontal MenuBar', () => {
    const menuBar = mount(
      <MenuBar horizontal>
        <Button>First</Button>
        <Button>Second</Button>
      </MenuBar>
    );
    expect(menuBar).to.have.className('kui-menu-bar__horizontal');
  });

  it('should render with none of the menu choices as active', () => {
    const menuBar = mount(
      <MenuBar>
        <Button>First</Button>
        <Button>Second</Button>
      </MenuBar>
    );
    expect(menuBar.find(Button).at(0)).to.not.have.className('active');
    expect(menuBar.find(Button).at(1)).to.not.have.className('active');
  });

  it('should render with the initialActiveMenuIndex menu choice as active', () => {
    const menuBar = mount(
      <MenuBar initialActiveMenuIndex={1}>
        <Button>First</Button>
        <Button>Second</Button>
      </MenuBar>
    );
    expect(menuBar.find(Button).at(1)).to.have.className('active');
  });
});
