import React from 'react';
import sinon from 'sinon';
import { expect } from 'chai';
import { mount } from 'enzyme';

import Modal from './../modal';

describe('Modal', () => {
  it('should render', () => {
    const modal = mount(
      <Modal title="Hello">
        <div>Content</div>
      </Modal>
    );

    expect(modal).to.have.className('klara-ui-modal');
    expect(modal.text()).to.have.string('Hello');
    expect(modal.text()).to.have.string('Content');
  });

  it('should support a custom footer', () => {
    const modal = mount(
      <Modal title="Hello" renderFooter={() => <div>Footer</div>}>
        <div>Content</div>
      </Modal>
    );

    expect(modal.text()).to.have.string('Footer');
  });

  it('should support notifications', () => {
    const modal = mount(
      <Modal title="Hello" notification={{ title: 'Hello World!' }}>
        <div>Content</div>
      </Modal>
    );

    expect(modal.text()).to.have.string('Hello World!');
  });

  it('should close on pressing Escape', () => {
    const onClose = sinon.spy();

    const modal = mount(
      <Modal title="Hello" onClose={onClose}>
        <div>Content</div>
      </Modal>
    );

    modal.instance().onKeyUp({ key: 'Escape' });
    modal.instance().onKeyUp({ key: 'Control' });
    modal.instance().onKeyUp({ key: 'Alt' });
    modal.instance().onKeyUp({ key: 'Backspace' });
    expect(onClose).to.have.been.calledOnce();
  });

  it('should close on clicking outside the container', () => {
    const onClose = sinon.spy();

    const modal = mount(
      <Modal title="Hello" onClose={onClose}>
        <div>Content</div>
      </Modal>
    );

    modal.find('.klara-ui-modal__container').simulate('click');
    modal.find('.klara-ui-modal').simulate('click');
    expect(onClose).to.have.been.calledOnce();
  });
});
