import React from 'react';
import { expect } from 'chai';
import { mount } from 'enzyme';
import sinon from 'sinon';

import Radiobuttons from './radiobuttons';
import Icon from '../icon/icon';

const propEquals = (prop, value) => node => node.prop(prop) === value;

const options = [
  { label: 'First Option', value: 'one' },
  { label: 'Second Option', value: 'two' },
  { label: 'Third Option', value: 'three' },
  { label: 'Fourth Option', value: 'four' },
];

describe('Radiobuttons', () => {
  it('should mount', () => {
    expect(mount(<Radiobuttons options={options} />)).to.exist();
  });

  it('should not select an option by default', () => {
    const wrapper = mount(<Radiobuttons options={options} />);

    expect(
      wrapper.find(Icon).filterWhere(propEquals('shape', 'radio_selected'))
    ).to.not.exist();
  });

  it('should select the matching option if given a value', () => {
    const wrapper = mount(<Radiobuttons selected="one" options={options} />);

    expect(
      wrapper
        .find(Icon)
        .filterWhere(propEquals('shape', 'radio_selected'))
        .parents()
        .first()
        .text()
    ).to.equal('First Option');
  });

  it('should call the onChange handler when clicking one of the options', () => {
    const onChangeStub = sinon.stub();
    const wrapper = mount(
      <Radiobuttons onChange={onChangeStub} options={options} />
    );

    wrapper
      .find('.kui-radiobuttons__option')
      .first()
      .simulate('click');

    expect(onChangeStub).to.have.been.called();
  });
});
