import React from 'react';
import PropTypes from 'prop-types';
import List from '../list/list';
import Icon from '../icon/icon';

const RadioButtons = ({ options, selected, onChange }) => (
  <div className="kui-radiobuttons">
    <List direction="left" padding="large">
      {options.map(option => (
        <div
          key={option.value}
          className="kui-radiobuttons__option"
          onClick={() => {
            onChange(option.value);
          }}
          tabIndex="0"
        >
          <Icon
            shape={selected === option.value ? 'radio_selected' : 'radio'}
          />
          {option.label}
        </div>
      ))}
    </List>
  </div>
);

RadioButtons.propTypes = {
  selected: PropTypes.string,
  options: PropTypes.arrayOf(
    PropTypes.shape({
      label: PropTypes.string.isRequired,
      value: PropTypes.string.isRequired,
    })
  ).isRequired,
  onChange: PropTypes.func.isRequired,
};

RadioButtons.defaultProps = {
  selected: null,
};

RadioButtons.propDescriptions = {
  selected: 'The currently selected option value',
  options:
    'A list of options to render as radio buttons. Each option is required to include label and value.',
  onChange: 'Called as the value changes',
};

export default RadioButtons;
