import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import Icon from '../icon/icon';

const typeMap = {
  robot: 'spinner--robot',
  fading: 'spinner--fading',
};

export default class Spinner extends Component {
  state = {
    showSpinner: !this.props.delay || false,
  };

  componentDidMount() {
    if (this.state.showSpinner) return;

    const { delay } = this.props;

    this.delayTimeout = setTimeout(() => {
      this.setState({ showSpinner: true });
    }, delay);
  }

  componentWillUnmount() {
    clearTimeout(this.delayTimeout);
  }

  convertedSize = numOrStr => {
    if (typeof numOrStr === 'string') {
      const sizes = { small: '64', medium: '128', large: '256' };
      return sizes[numOrStr];
    }
    return numOrStr;
  };

  render() {
    const { className, type, light, size } = this.props;

    const { showSpinner } = this.state;

    const classes = classnames(typeMap[type] || typeMap.robot, className, {
      'spinner--light': light,
      'spinner--fadein': showSpinner,
    });
    return (
      <React.Fragment>
        {showSpinner && (
          <Icon
            shape="logo"
            className={classes}
            size={this.convertedSize(size)}
          />
        )}
      </React.Fragment>
    );
  }
}

Spinner.defaultProps = {
  className: '',
  type: 'robot',
  size: 128,
  light: false,
  delay: 0,
};

Spinner.propTypes = {
  className: PropTypes.string,
  type: PropTypes.string,
  size: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
  light: PropTypes.bool,
  delay: PropTypes.number,
};
