import React from 'react';
import { expect } from 'chai';
import { mount } from 'enzyme';
import sinon from 'sinon';

import Spinner from '../spinner';
import Icon from '../../icon/icon';

const now = 1516627620000; // 2018-01-22 14:27.00 UTC+1

describe('Spinner', () => {
  let clock;
  beforeEach(() => {
    clock = sinon.useFakeTimers(now);
  });

  afterEach(() => {
    clock.restore();
  });

  it('should render a spinner', () => {
    const spinner = mount(<Spinner />);
    expect(spinner.find(Icon).hasClass('spinner--robot')).to.equal(true);
  });

  it('should render a fading spinner when receiving the "fading" type', () => {
    const spinner = mount(<Spinner type="fading" />);
    expect(spinner.find(Icon).hasClass('spinner--fading')).to.equal(true);
  });

  it('should set the width and height to the given size prop', () => {
    const spinner = mount(<Spinner size={10} />);
    expect(
      spinner
        .find('svg')
        .instance()
        .getAttribute('width')
    ).to.be.equal('10');
    expect(
      spinner
        .find('svg')
        .instance()
        .getAttribute('height')
    ).to.be.equal('10');
  });

  it('should apply classnames given via props', () => {
    const spinner = mount(<Spinner className="testing-classnames" />);
    expect(spinner.find(Icon).hasClass('testing-classnames')).to.equal(true);
    expect(spinner.find(Icon).hasClass('spinner--robot')).to.equal(true);
  });

  it('sohuld add a one second delay via props', () => {
    const spinner = mount(
      <Spinner delay={1000} className="'testing-classnames" />
    );

    expect(spinner.find(Icon)).to.not.exist();

    clock.tick(2000);
    spinner.update();

    expect(spinner.find(Icon)).to.exist();
  });
});
