import React from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';

const BASE_CLASS = 'klara-ui-switch';

function prefix(className) {
  return `${BASE_CLASS}__${className}`;
}
class Switch extends React.Component {
  onChange = event => {
    this.props.onChange(event.target.checked, event);
  };

  render() {
    const { value, label, className, disabled } = this.props;
    return (
      <label className={classnames(BASE_CLASS, className)}>
        <input
          className={prefix('input')}
          type="checkbox"
          ref={this.inputRef}
          checked={value}
          onChange={this.onChange}
          disabled={disabled}
        />
        <div
          className={classnames(prefix('wrapper'), {
            [prefix('wrapper--disabled')]: disabled,
          })}
        >
          <div
            className={classnames(prefix('track'), {
              [prefix('track--on')]: Boolean(value),
            })}
          />
          <div
            className={classnames(prefix('knob'), {
              [prefix('knob--on')]: Boolean(value),
            })}
          />
        </div>
        {label && <span className={prefix('label-text')}>{label}</span>}
      </label>
    );
  }
}

Switch.propTypes = {
  value: PropTypes.bool,
  onChange: PropTypes.func,
  label: PropTypes.string,
  className: PropTypes.string,
  disabled: PropTypes.bool,
};

Switch.defaultProps = {
  value: false,
  onChange: () => {},
  label: null,
  className: '',
  disabled: false,
};

Switch.propDescriptions = {
  value: 'True and false maps to "on" and "off"',
  onChange:
    'Callback which runs as the switch changes value, new value is passed as the only argument',
  label:
    'A descriptive label. Will be vertically centered to the switch itself',
  className: 'Any combination of CSS classnames',
};

export default Switch;
