import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Icon from '../../components/icon/icon';

class Tab extends React.Component {
  state = {
    icon: 'remove_outline',
  };

  onIconClick = e => {
    e.stopPropagation();
    this.props.onClose(this.props.tab);
  };

  onIconMouseEnter = () => this.setState({ icon: 'remove' });

  onIconMouseLeave = () => this.setState({ icon: 'remove_outline' });

  onClick = () => this.props.onClick(this.props.tab);

  render() {
    const { icon } = this.state;
    const { active, tab, immortal } = this.props;

    return (
      <div
        onClick={this.onClick}
        title={tab.title}
        className={cx('klara-ui-tabs__tab', {
          'klara-ui-tabs__tab--active': active,
        })}
      >
        <div className="klara-ui-tabs__tab__background" />
        <span className="klara-ui-tabs__tab__title">{tab.title}</span>
        {!immortal && (
          <span
            className="klara-ui-tabs__tab__close"
            onMouseEnter={this.onIconMouseEnter}
            onMouseLeave={this.onIconMouseLeave}
          >
            <Icon shape={icon} small onClick={this.onIconClick} />
          </span>
        )}
      </div>
    );
  }
}

Tab.propTypes = {
  active: PropTypes.bool,
  immortal: PropTypes.bool,
  onClick: PropTypes.func,
  onClose: PropTypes.func,
  tab: PropTypes.shape({
    title: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
    id: PropTypes.string.isRequired,
  }).isRequired,
};

Tab.defaultProps = {
  active: false,
  immortal: false,
  onClick: () => {},
  onClose: () => {},
};

export default Tab;
