import React from 'react';
import PropTypes from 'prop-types';

export default class InputText extends React.PureComponent {
  onChange = ({ target }) => this.props.onChange(target.value);

  focus() {
    this.inputRef.focus();
  }

  fillRef = ref => {
    this.inputRef = ref;
  };

  render() {
    const { className, ...attrs } = this.props;
    return (
      <input
        {...attrs}
        ref={this.fillRef}
        className={`${className} text-field__control--native`}
        onChange={this.onChange}
      />
    );
  }
}

InputText.propTypes = {
  className: PropTypes.string.isRequired,
  disabled: PropTypes.bool.isRequired,
  maxLength: PropTypes.number.isRequired,
  onBlur: PropTypes.func.isRequired,
  onChange: PropTypes.func.isRequired,
  onFocus: PropTypes.func.isRequired,
  type: PropTypes.oneOf(['text', 'password', 'email', 'url', 'number']),
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
};

InputText.defaultProps = {
  type: 'text',
  value: '',
};
