import React from 'react';
import { expect } from 'chai';
import { mount } from 'enzyme';

import TextHighlight from '../textHighlight';

describe('TextHighlight', () => {
  it('should not alter text content', () => {
    const wrapper = mount(
      <div>
        <TextHighlight highlight="bar">foobar and more bare</TextHighlight>
      </div>
    );
    expect(wrapper.text()).to.equal('foobar and more bare');
  });

  it('should not highlight anything for empty input', () => {
    const wrapper = mount(
      <div>
        <TextHighlight highlight="">foobar with bar and more</TextHighlight>
      </div>
    );

    expect(wrapper.find('.text-highlight__fragment')).to.not.exist();
    expect(wrapper.text()).to.equal('foobar with bar and more');
  });

  it('should highlight all matches', () => {
    const wrapper = mount(
      <div>
        <TextHighlight highlight="bar">foobar with bar and more</TextHighlight>
      </div>
    );

    const textFragments = wrapper.find('mark').map(n => n.text());
    expect(textFragments).to.have.length(2);
    expect(textFragments).to.deep.equal(['bar', 'bar']);
  });

  it('should highlight case insensitive', () => {
    const wrapper = mount(
      <div>
        <TextHighlight highlight="bar">foobar with Bar</TextHighlight>
      </div>
    );

    const textFragments = wrapper.find('mark').map(n => n.text());
    expect(textFragments).to.have.length(2);
    expect(textFragments).to.deep.equal(['bar', 'Bar']);
  });

  it('should use render prop if provided', () => {
    const wrapper = mount(
      <div>
        <TextHighlight
          highlight="bar"
          renderHighlight={(fragment, highlightProps) => (
            <article {...highlightProps}>{fragment}</article>
          )}
        >
          foobar with Bar
        </TextHighlight>
      </div>
    );

    const textFragments = wrapper.find('article').map(n => n.text());
    expect(textFragments).to.have.length(2);
    expect(textFragments).to.deep.equal(['bar', 'Bar']);
  });

  it('should hand regex like string', () => {
    const wrapper = mount(
      <div>
        <TextHighlight highlight=".*">string.*</TextHighlight>
      </div>
    );

    const textFragments = wrapper.find('mark').map(n => n.text());
    expect(textFragments).to.have.length(1);
    expect(textFragments).to.deep.equal(['.*']);
    expect(wrapper.text()).to.deep.equal('string.*');
  });
});
