import React, { Fragment } from 'react';
import PropTypes from 'prop-types';

function splitOnMatches(string, subString) {
  const matchIndices = [];
  let currentIndex = 0;
  while (
    string.toLowerCase().indexOf(subString.toLowerCase(), currentIndex) !== -1
  ) {
    currentIndex = string
      .toLowerCase()
      .indexOf(subString.toLowerCase(), currentIndex);
    matchIndices.push(currentIndex);
    matchIndices.push(currentIndex + subString.length);
    currentIndex += 1;
  }

  if (!matchIndices.length) {
    return [string];
  }

  const parts = [];
  matchIndices.reduce((previous, index) => {
    const part = string.slice(previous, index);
    parts.push(part);
    return previous + part.length;
  }, 0);
  return parts.concat(string.substr(matchIndices[matchIndices.length - 1]));
}

const TextHighlight = ({ children, highlight, renderHighlight }) => {
  if (!highlight.length) {
    return children;
  }
  const parts = splitOnMatches(children, highlight);
  return (
    <Fragment>
      {parts.map(
        (part, key) =>
          part.toLowerCase() === highlight.toLowerCase()
            ? renderHighlight(part, { key })
            : part
      )}
    </Fragment>
  );
};

TextHighlight.propTypes = {
  children: PropTypes.string.isRequired,
  highlight: PropTypes.string.isRequired,
  renderHighlight: PropTypes.func,
};

TextHighlight.defaultProps = {
  renderHighlight: (fragment, highlightProps) => (
    <mark {...highlightProps}>{fragment}</mark>
  ),
};

TextHighlight.propDescriptions = {
  children: 'String to be highlighted',
  highlight: 'Substring to highlight',
  renderHighlight:
    'Optional render prop to control decoration of highlighted fragments. Called with the string to highlight and highligtProps to be spread on the element',
};

export default TextHighlight;
