import React, { cloneElement } from 'react';
import PropTypes from 'prop-types';
import List from '../list/list';

const ToggleButtonGroup = ({ children, activeIndex, onActiveIndexChange }) => (
  <List direction="left" padding="small" className="toggle-button-group">
    {React.Children.map(children, (child, index) => {
      const buttonProps = {
        ...child.props,
        active: index === activeIndex,
        compact: true,
        type: 'ghost',
        onClick: evt => {
          onActiveIndexChange(index);
          if (child.props.onClick) {
            child.props.onClick(evt);
          }
        },
      };
      return cloneElement(child, buttonProps);
    })}
  </List>
);

ToggleButtonGroup.defaultProps = {
  onActiveIndexChange: () => {},
};

ToggleButtonGroup.propTypes = {
  activeIndex: PropTypes.number.isRequired,
  children: PropTypes.node.isRequired,
  onActiveIndexChange: PropTypes.func,
};

export default ToggleButtonGroup;
